@@ -13,14 +13,42 @@ LOG
 #ifndef INCLUDE_CPPEXTERN_H_
 #define INCLUDE_CPPEXTERN_H_
 
-#ifdef NT
-#pragma warning( disable : 4244 )
-#pragma warning( disable : 4305 )
-#pragma warning( disable : 4091 )
-#endif
+#include "Base/config.h"
+#include "Base/GemExportDef.h"
 
 #include "m_pd.h"
-#include "Base/GemExportDef.h"
+#include "Base/GemVersion.h"
+
+#include <new>
+
+
+/*-----------------------------------------------------------------
+-------------------------------------------------------------------
+CLASS
+    GemException
+    
+    an exception class...
+
+DESCRIPTION
+    
+    this is a class, we can throw on creation, 
+    to make sure that the pd-object can not be created
+
+
+    
+-----------------------------------------------------------------*/
+class GEM_EXTERN GemException
+{
+ public:
+  GemException() throw();
+  GemException(const char*error) throw();
+  virtual ~GemException() throw();
+  
+  virtual const char *what() const throw();
+  virtual void report(const char*origin=NULL) const throw();
+ private:
+  const char*ErrorString;
+};
 
 class CPPExtern;
 
@@ -106,8 +134,8 @@ class GEM_EXTERN CPPExtern
 
 	//////////
 	// my name
+	static char          *m_holdname;
 	t_symbol             *m_objectname;
-        void                  setCPPObjectName(char* name);
 
     protected:
     	
@@ -121,6 +149,17 @@ class GEM_EXTERN CPPExtern
         // The canvas that the object is in
         t_canvas            *m_canvas;
 
+ public:
+        // these call pd's print-functions, and eventually prepend the object's name
+	void            startpost(const char*format, ...);
+	void            post(const char*format, ...);
+	void            endpost(void);
+	void            verbose(const int level, const char*format, ...);
+	void            error(const char*format, ...); /* internally uses pd_error() */
+
+ private:
+	bool m_endpost; /* internal state for startpost/post/endpost */
+	static bool checkGemVersion(int major, int minor);
 };
 
 // This has a dummy arg so that NT won't complain
@@ -151,37 +190,38 @@ static void obj_setupCallback(t_class *classPtr);
 // NO ARGUMENTS
 /////////////////////////////////////////////////
 #define CPPEXTERN_NEW(NEW_CLASS)    	    	    	    	\
-    REAL_NEW(NEW_CLASS, _setup, _class)
-
+    REAL_NEW(NEW_CLASS)
 //
 // ONE ARGUMENT
 /////////////////////////////////////////////////
 #define CPPEXTERN_NEW_WITH_ONE_ARG(NEW_CLASS, TYPE, PD_TYPE)    \
-    REAL_NEW_WITH_ARG(NEW_CLASS, _setup, _class, TYPE, PD_TYPE)
-
+    REAL_NEW_WITH_ARG(NEW_CLASS, TYPE, PD_TYPE)
 //
 // GIMME ARGUMENT
 /////////////////////////////////////////////////
 #define CPPEXTERN_NEW_WITH_GIMME(NEW_CLASS)  	    	    	\
-    REAL_NEW_WITH_GIMME(NEW_CLASS, _setup, _class)
-
+    REAL_NEW_WITH_GIMME(NEW_CLASS)
 //
 // TWO ARGUMENTS
 /////////////////////////////////////////////////
 #define CPPEXTERN_NEW_WITH_TWO_ARGS(NEW_CLASS, TYPE, PD_TYPE, TTWO, PD_TWO)	\
-    REAL_NEW_WITH_ARG_ARG(NEW_CLASS, _setup, _class, TYPE, PD_TYPE, TTWO, PD_TWO)
-
+    REAL_NEW_WITH_ARG_ARG(NEW_CLASS, TYPE, PD_TYPE, TTWO, PD_TWO)
 //
 // THREE ARGUMENTS
 /////////////////////////////////////////////////
 #define CPPEXTERN_NEW_WITH_THREE_ARGS(NEW_CLASS, TYPE, PD_TYPE, TTWO, PD_TWO, TTHREE, PD_THREE)	\
-    REAL_NEW_WITH_ARG_ARG_ARG(NEW_CLASS, _setup, _class, TYPE, PD_TYPE, TTWO, PD_TWO, TTHREE, PD_THREE)
-
+    REAL_NEW_WITH_ARG_ARG_ARG(NEW_CLASS, TYPE, PD_TYPE, TTWO, PD_TWO, TTHREE, PD_THREE)
 //
 // FOUR ARGUMENTS
 /////////////////////////////////////////////////
 #define CPPEXTERN_NEW_WITH_FOUR_ARGS(NEW_CLASS, TYPE, PD_TYPE, TTWO, PD_TWO, TTHREE, PD_THREE, TFOUR, PD_FOUR) \
-    REAL_NEW_WITH_ARG_ARG_ARG_ARG(NEW_CLASS, _setup, _class, TYPE, PD_TYPE, TTWO, PD_TWO, TTHREE, PD_THREE, TFOUR, PD_FOUR)
+    REAL_NEW_WITH_ARG_ARG_ARG_ARG(NEW_CLASS, TYPE, PD_TYPE, TTWO, PD_TWO, TTHREE, PD_THREE, TFOUR, PD_FOUR)
+//
+// FIVE ARGUMENTS
+/////////////////////////////////////////////////
+#define CPPEXTERN_NEW_WITH_FIVE_ARGS(NEW_CLASS, TYPE, PD_TYPE, TTWO, PD_TWO, TTHREE, PD_THREE, TFOUR, PD_FOUR, TFIVE, PD_FIVE) \
+    REAL_NEW_WITH_ARG_ARG_ARG_ARG_ARG(NEW_CLASS, TYPE, PD_TYPE, TTWO, PD_TWO, TTHREE, PD_THREE, TFOUR, PD_FOUR, TFIVE, PD_FIVE)
+	
 
 
 //////////////////////////////////////////////////////////////////////////////
@@ -190,6 +230,18 @@ static void obj_setupCallback(t_class *classPtr);
 //
 ///////////////////////////////////////////////////////////////////////////////
 
+///////////////////////////////////////////////////////////////////////////////
+// static class:
+//   by default classes are declared static
+//   however, sometimes we need classes not-static, so we can refer to them
+//   from other classes
+///////////////////////////////////////////////////////////////////////////////
+#ifdef NO_STATIC_CLASS
+# define STATIC_CLASS
+#else
+# define STATIC_CLASS static
+#endif
+
 ///////////////////////////////////////////////////////////////////////////////
 // auto registering a class
 // this creates a dummy class, whose constructor calls the setup-function 
@@ -198,18 +250,18 @@ static void obj_setupCallback(t_class *classPtr);
 ///////////////////////////////////////////////////////////////////////////////
 #ifdef NO_AUTO_REGISTER_CLASS
 // if NO_AUTO_REGISTER_CLASS is defined, we will not register the class
-# define AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION)
+# define AUTO_REGISTER_CLASS(NEW_CLASS)
 #else
 // for debugging we can show the which classes are auto-registering
 # if 0
-#  define POST_AUTOREGISTER(NEW_CLASS) post("auto-registering: "#NEW_CLASS);
+#  define POST_AUTOREGISTER(NEW_CLASS) post("auto-registering: "#NEW_CLASS)
 # else
 #  define POST_AUTOREGISTER(NEW_CLASS)
 # endif
-# define AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION)			\
+# define AUTO_REGISTER_CLASS(NEW_CLASS)			\
   class NEW_CLASS ## _cppclass {					\
   public:								\
-  NEW_CLASS ## _cppclass() {POST_AUTOREGISTER(NEW_CLASS); NEW_CLASS ## SETUP_FUNCTION(); } \
+  NEW_CLASS ## _cppclass() {POST_AUTOREGISTER(NEW_CLASS); NEW_CLASS ## _setup(); } \
 };									\
   static NEW_CLASS ## _cppclass NEW_CLASS ## _instance;
 #endif
@@ -217,196 +269,263 @@ static void obj_setupCallback(t_class *classPtr);
 ///////////////////////////////////////////////////////////////////////////////
 // setting the help-symbol
 ///////////////////////////////////////////////////////////////////////////////
-#ifndef HELPSYMBOL_BASE
-# define HELPSYMBOL_BASE ""
-#endif
+#if defined HELPSYMBOL_BASE || defined HELPSYMBOL
+# ifndef HELPSYMBOL_BASE
+#  define HELPSYMBOL_BASE ""
+# endif
+
+# ifndef HELPSYMBOL
+#  define SET_HELPSYMBOL(NEW_CLASS)                                     \
+  class_sethelpsymbol(NEW_CLASS ## _class, gensym(HELPSYMBOL_BASE #NEW_CLASS))
+# else
+#  define SET_HELPSYMBOL(NEW_CLASS)				\
+    class_sethelpsymbol(NEW_CLASS ## _class, gensym(HELPSYMBOL_BASE HELPSYMBOL))
+# endif
 
-#ifdef HELPSYMBOL
-# define SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME)				\
-  class_sethelpsymbol(NEW_CLASS ## EXTERN_NAME, gensym(HELPSYMBOL_BASE HELPSYMBOL));
 #else 
-# define SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME)			\
-  class_sethelpsymbol(NEW_CLASS ## EXTERN_NAME, gensym(HELPSYMBOL_BASE#NEW_CLASS));
+# define SET_HELPSYMBOL(NEW_CLASS)
 #endif /* HELPSYMBOL */
 
+
+///////////////////////////////////////////////////////////////////////////////
+// setting the class-flags
+///////////////////////////////////////////////////////////////////////////////
+#ifndef GEM_CLASSFLAGS
+# define GEM_CLASSFLAGS 0
+#endif
 ///////////////////////////////////////////////////////////////////////////////
 // no args
 ///////////////////////////////////////////////////////////////////////////////
-#define REAL_NEW(NEW_CLASS, SETUP_FUNCTION, EXTERN_NAME)        \
-static t_class * NEW_CLASS ## EXTERN_NAME;    	    	    	\
-void * EXTERN_NAME ## NEW_CLASS ()                              \
+#define REAL_NEW(NEW_CLASS)        \
+STATIC_CLASS t_class * NEW_CLASS ## _class;    	    	    	\
+static void* create_ ## NEW_CLASS ()                              \
 {     	    	    	    	    	    	    	    	\
-    Obj_header *obj = new (pd_new(NEW_CLASS ## EXTERN_NAME),(void *)NULL) Obj_header; \
+  try{	    	    	    	    	    	    	    	\
+    Obj_header *obj = new (pd_new(NEW_CLASS ## _class),(void *)NULL) Obj_header; \
     CPPExtern::m_holder = &obj->pd_obj;                         \
+    CPPExtern::m_holdname=(char*)#NEW_CLASS;                    \
     obj->data = new NEW_CLASS;                                  \
     CPPExtern::m_holder = NULL;                                 \
-    obj->data->setCPPObjectName(#NEW_CLASS);                \
+    CPPExtern::m_holdname=NULL;                                 \
     return(obj);                                                \
-}   	    	    	    	    	    	    	    	\
-extern "C" {	    	    	    	    	    	    	\
-void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
-{   	    	    	    	    	    	    	    	\
-    NEW_CLASS ## EXTERN_NAME = class_new(                       \
-    	     	gensym(#NEW_CLASS), 	    	    	     	\
-    	    	(t_newmethod)EXTERN_NAME ## NEW_CLASS,	    	\
-    	    	(t_method)&NEW_CLASS::obj_freeCallback,         \
-    	     	sizeof(Obj_header), 0,                          \
-    	     	A_NULL);                                        \
-    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
- }									\
-}									\
-  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
+  } catch (GemException e) {e.report(CPPExtern::m_holdname); return NULL;} \
+}                                                               \
+  extern "C" {                                                  \
+    void NEW_CLASS ## _setup()                          \
+    {                                                           \
+      static bool firsttime=true; if(!firsttime)return; firsttime=false; \
+      NEW_CLASS ## _class = class_new(                     \
+                                           gensym(#NEW_CLASS),  \
+                                           (t_newmethod)create_ ## NEW_CLASS, \
+                                           (t_method)&NEW_CLASS::obj_freeCallback, \
+                                           sizeof(Obj_header), GEM_CLASSFLAGS, \
+                                           A_NULL);                     \
+      SET_HELPSYMBOL(NEW_CLASS);                           \
+      NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## _class);      \
+    }                                                                   \
+  }                                                                     \
+  AUTO_REGISTER_CLASS(NEW_CLASS);
 
 
 ///////////////////////////////////////////////////////////////////////////////
 // one arg
 ///////////////////////////////////////////////////////////////////////////////
-#define REAL_NEW_WITH_ARG(NEW_CLASS, SETUP_FUNCTION, EXTERN_NAME, VAR_TYPE, PD_TYPE) \
-static t_class * NEW_CLASS ## EXTERN_NAME;    	    	    	\
-void * EXTERN_NAME ## NEW_CLASS (VAR_TYPE arg)                  \
+#define REAL_NEW_WITH_ARG(NEW_CLASS, VAR_TYPE, PD_TYPE) \
+STATIC_CLASS t_class * NEW_CLASS ## _class;    	    	    	\
+static void* create_ ## NEW_CLASS (VAR_TYPE arg)                  \
 {     	    	    	    	    	    	    	    	\
-    Obj_header *obj = new (pd_new(NEW_CLASS ## EXTERN_NAME),(void *)NULL) Obj_header; \
+  try{	    	    	    	    	    	    	    	\
+    Obj_header *obj = new (pd_new(NEW_CLASS ## _class),(void *)NULL) Obj_header; \
     CPPExtern::m_holder = &obj->pd_obj;                         \
+    CPPExtern::m_holdname=(char*)#NEW_CLASS;                    \
     obj->data = new NEW_CLASS(arg);                             \
     CPPExtern::m_holder = NULL;                                 \
-    obj->data->setCPPObjectName(#NEW_CLASS);                \
+    CPPExtern::m_holdname=NULL;                                 \
     return(obj);                                                \
+  } catch (GemException e) {e.report(); return NULL;}           \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
-void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
+void NEW_CLASS ## _setup()    	    	    	    	\
 {   	    	    	    	    	    	    	    	\
-    NEW_CLASS ## EXTERN_NAME = class_new(                       \
+    NEW_CLASS ## _class = class_new(                       \
     	     	gensym(#NEW_CLASS), 	    	    	    	\
-    	    	(t_newmethod)EXTERN_NAME ## NEW_CLASS,	    	\
+    	    	(t_newmethod)create_ ## NEW_CLASS,	    	\
     	    	(t_method)&NEW_CLASS::obj_freeCallback,         \
-    	     	sizeof(Obj_header), 0,                          \
+    	     	sizeof(Obj_header), GEM_CLASSFLAGS,             \
     	     	PD_TYPE,                                        \
     	     	A_NULL);      	    	    	    	    	\
-    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+    SET_HELPSYMBOL(NEW_CLASS);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## _class);	\
  }									\
 }									\
-  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
+  AUTO_REGISTER_CLASS(NEW_CLASS);
 
 ///////////////////////////////////////////////////////////////////////////////
 // gimme arg
 ///////////////////////////////////////////////////////////////////////////////
-#define REAL_NEW_WITH_GIMME(NEW_CLASS, SETUP_FUNCTION, EXTERN_NAME) \
-static t_class * NEW_CLASS ## EXTERN_NAME;    	    	    	\
-void * EXTERN_NAME ## NEW_CLASS (t_symbol *, int argc, t_atom *argv) \
+#define REAL_NEW_WITH_GIMME(NEW_CLASS) \
+STATIC_CLASS t_class * NEW_CLASS ## _class;    	    	    	\
+static void* create_ ## NEW_CLASS (t_symbol *s, int argc, t_atom *argv) \
 {     	    	    	    	    	    	    	    	\
-    Obj_header *obj = new (pd_new(NEW_CLASS ## EXTERN_NAME),(void *)NULL) Obj_header; \
+  try{	    	    	    	    	    	    	    	\
+    Obj_header *obj = new (pd_new(NEW_CLASS ## _class),(void *)NULL) Obj_header; \
     CPPExtern::m_holder = &obj->pd_obj;                         \
+    CPPExtern::m_holdname=(char*)s->s_name;                     \
     obj->data = new NEW_CLASS(argc, argv);                      \
-    CPPExtern::m_holder = NULL;                                 \
-    obj->data->setCPPObjectName(#NEW_CLASS);                 \
+    CPPExtern::m_holder=NULL;                                   \
+    CPPExtern::m_holdname=NULL;                                 \
     return(obj);                                                \
+  } catch (GemException e) {e.report(); return NULL;}           \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
-void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
+void NEW_CLASS ## _setup()    	    	    	    	\
 {   	    	    	    	    	    	    	    	\
-    NEW_CLASS ## EXTERN_NAME = class_new(                       \
+    NEW_CLASS ## _class = class_new(                       \
     	     	gensym(#NEW_CLASS), 	    	    	    	\
-    	    	(t_newmethod)EXTERN_NAME ## NEW_CLASS,	    	\
+    	    	(t_newmethod)create_ ## NEW_CLASS,	    	\
     	    	(t_method)&NEW_CLASS::obj_freeCallback,         \
-    	     	sizeof(Obj_header), 0,                          \
+    	     	sizeof(Obj_header), GEM_CLASSFLAGS,             \
     	     	A_GIMME,                                        \
     	     	A_NULL);      	    	    	    	    	\
-    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+    SET_HELPSYMBOL(NEW_CLASS);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## _class);	\
  }									\
 }									\
-  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
+  AUTO_REGISTER_CLASS(NEW_CLASS);
 
 ///////////////////////////////////////////////////////////////////////////////
 // two args
 ///////////////////////////////////////////////////////////////////////////////
-#define REAL_NEW_WITH_ARG_ARG(NEW_CLASS, SETUP_FUNCTION, EXTERN_NAME, ONE_VAR_TYPE, ONE_PD_TYPE, TWO_VAR_TYPE, TWO_PD_TYPE) \
-static t_class * NEW_CLASS ## EXTERN_NAME;    	    	    	\
-void * EXTERN_NAME ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo) \
+#define REAL_NEW_WITH_ARG_ARG(NEW_CLASS, ONE_VAR_TYPE, ONE_PD_TYPE, TWO_VAR_TYPE, TWO_PD_TYPE) \
+STATIC_CLASS t_class * NEW_CLASS ## _class;    	    	    	\
+static void* create_ ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo) \
 {     	    	    	    	    	    	    	    	\
-    Obj_header *obj = new (pd_new(NEW_CLASS ## EXTERN_NAME),(void *)NULL) Obj_header; \
+  try{	    	    	    	    	    	    	    	\
+    Obj_header *obj = new (pd_new(NEW_CLASS ## _class),(void *)NULL) Obj_header; \
     CPPExtern::m_holder = &obj->pd_obj;                         \
+    CPPExtern::m_holdname=(char*)#NEW_CLASS;                    \
     obj->data = new NEW_CLASS(arg, argtwo);                     \
     CPPExtern::m_holder = NULL;                                 \
-    obj->data->setCPPObjectName(#NEW_CLASS);                \
+    CPPExtern::m_holdname=NULL;                                 \
     return(obj);                                                \
+  } catch (GemException e) {e.report(); return NULL;}           \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
-void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
+void NEW_CLASS ## _setup()    	    	    	    	\
 {   	    	    	    	    	    	    	    	\
-    NEW_CLASS ## EXTERN_NAME = class_new(                       \
+    NEW_CLASS ## _class = class_new(                       \
     	     	gensym(#NEW_CLASS), 	    	    	    	\
-    	    	(t_newmethod)EXTERN_NAME ## NEW_CLASS,	    	\
+    	    	(t_newmethod)create_ ## NEW_CLASS,	    	\
     	    	(t_method)&NEW_CLASS::obj_freeCallback,         \
-    	     	sizeof(Obj_header), 0,                          \
+    	     	sizeof(Obj_header), GEM_CLASSFLAGS,             \
     	     	ONE_PD_TYPE, TWO_PD_TYPE,                       \
     	     	A_NULL);      	    	    	    	    	\
-    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+    SET_HELPSYMBOL(NEW_CLASS);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## _class);	\
  }									\
 }									\
-  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
+  AUTO_REGISTER_CLASS(NEW_CLASS);
 
 ///////////////////////////////////////////////////////////////////////////////
 // three args
 ///////////////////////////////////////////////////////////////////////////////
-#define REAL_NEW_WITH_ARG_ARG_ARG(NEW_CLASS, SETUP_FUNCTION, EXTERN_NAME, ONE_VAR_TYPE, ONE_PD_TYPE, TWO_VAR_TYPE, TWO_PD_TYPE, THREE_VAR_TYPE, THREE_PD_TYPE) \
-static t_class * NEW_CLASS ## EXTERN_NAME;    	    	    	\
-void * EXTERN_NAME ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo, THREE_VAR_TYPE argthree) \
+#define REAL_NEW_WITH_ARG_ARG_ARG(NEW_CLASS, ONE_VAR_TYPE, ONE_PD_TYPE, TWO_VAR_TYPE, TWO_PD_TYPE, THREE_VAR_TYPE, THREE_PD_TYPE) \
+STATIC_CLASS t_class * NEW_CLASS ## _class;    	    	    	\
+static void* create_ ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo, THREE_VAR_TYPE argthree) \
 {     	    	    	    	    	    	    	    	\
-    Obj_header *obj = new (pd_new(NEW_CLASS ## EXTERN_NAME),(void *)NULL) Obj_header; \
+  try{	    	    	    	    	    	    	    	\
+    Obj_header *obj = new (pd_new(NEW_CLASS ## _class),(void *)NULL) Obj_header; \
     CPPExtern::m_holder = &obj->pd_obj;                         \
+    CPPExtern::m_holdname=(char*)#NEW_CLASS;                    \
     obj->data = new NEW_CLASS(arg, argtwo, argthree);           \
     CPPExtern::m_holder = NULL;                                 \
-    obj->data->setCPPObjectName(#NEW_CLASS);                \
+    CPPExtern::m_holdname=NULL;                                 \
     return(obj);                                                \
+  } catch (GemException e) {e.report(); return NULL;}           \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
-void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
+void NEW_CLASS ## _setup()    	    	    	    	\
 {   	    	    	    	    	    	    	    	\
-    NEW_CLASS ## EXTERN_NAME = class_new(                       \
+    NEW_CLASS ## _class = class_new(                       \
     	     	gensym(#NEW_CLASS), 	    	    	    	\
-    	    	(t_newmethod)EXTERN_NAME ## NEW_CLASS,	    	\
+    	    	(t_newmethod)create_ ## NEW_CLASS,	    	\
     	    	(t_method)&NEW_CLASS::obj_freeCallback,         \
-    	     	sizeof(Obj_header), 0,                          \
+    	     	sizeof(Obj_header), GEM_CLASSFLAGS,             \
     	     	ONE_PD_TYPE, TWO_PD_TYPE, THREE_PD_TYPE,        \
     	     	A_NULL);      	    	    	    	    	\
-    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+    SET_HELPSYMBOL(NEW_CLASS);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## _class);	\
  }									\
 }									\
-  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
+  AUTO_REGISTER_CLASS(NEW_CLASS);
 
 ///////////////////////////////////////////////////////////////////////////////
 // four args
 ///////////////////////////////////////////////////////////////////////////////
-#define REAL_NEW_WITH_ARG_ARG_ARG_ARG(NEW_CLASS, SETUP_FUNCTION, EXTERN_NAME, ONE_VAR_TYPE, ONE_PD_TYPE, TWO_VAR_TYPE, TWO_PD_TYPE, THREE_VAR_TYPE, THREE_PD_TYPE, FOUR_VAR_TYPE, FOUR_PD_TYPE) \
-static t_class * NEW_CLASS ## EXTERN_NAME;    	    	    	\
-void * EXTERN_NAME ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo, THREE_VAR_TYPE argthree, FOUR_VAR_TYPE argfour) \
+#define REAL_NEW_WITH_ARG_ARG_ARG_ARG(NEW_CLASS, ONE_VAR_TYPE, ONE_PD_TYPE, TWO_VAR_TYPE, TWO_PD_TYPE, THREE_VAR_TYPE, THREE_PD_TYPE, FOUR_VAR_TYPE, FOUR_PD_TYPE) \
+STATIC_CLASS t_class * NEW_CLASS ## _class;    	    	    	\
+static void* create_ ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo, THREE_VAR_TYPE argthree, FOUR_VAR_TYPE argfour) \
 {     	    	    	    	    	    	    	    	\
-    Obj_header *obj = new (pd_new(NEW_CLASS ## EXTERN_NAME),(void *)NULL) Obj_header; \
+  try{	    	    	    	    	    	    	    	\
+    Obj_header *obj = new (pd_new(NEW_CLASS ## _class),(void *)NULL) Obj_header; \
     CPPExtern::m_holder = &obj->pd_obj;                         \
+    CPPExtern::m_holdname=(char*)#NEW_CLASS;                    \
     obj->data = new NEW_CLASS(arg, argtwo, argthree, argfour);  \
     CPPExtern::m_holder = NULL;                                 \
-    obj->data->setCPPObjectName(#NEW_CLASS);                \
+    CPPExtern::m_holdname=NULL;                                 \
     return(obj);                                                \
+  } catch (GemException e) {e.report(); return NULL;}           \
 }   	    	    	    	    	    	    	    	\
 extern "C" {	    	    	    	    	    	    	\
-void NEW_CLASS ## SETUP_FUNCTION()    	    	    	    	\
+void NEW_CLASS ## _setup()    	    	    	    	\
 {   	    	    	    	    	    	    	    	\
-    NEW_CLASS ## EXTERN_NAME = class_new(                       \
+    NEW_CLASS ## _class = class_new(                       \
     	     	gensym(#NEW_CLASS), 	    	    	    	\
-    	    	(t_newmethod)EXTERN_NAME ## NEW_CLASS,	    	\
+    	    	(t_newmethod)create_ ## NEW_CLASS,	    	\
     	    	(t_method)&NEW_CLASS::obj_freeCallback,         \
-    	     	sizeof(Obj_header), 0,                          \
+    	     	sizeof(Obj_header), GEM_CLASSFLAGS,             \
     	     	ONE_PD_TYPE, TWO_PD_TYPE, THREE_PD_TYPE, FOUR_PD_TYPE,	\
     	     	A_NULL);						\
-    SET_HELPSYMBOL(NEW_CLASS, EXTERN_NAME);				\
-    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## EXTERN_NAME);	\
+    SET_HELPSYMBOL(NEW_CLASS);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## _class);	\
  }									\
 }									\
-  AUTO_REGISTER_CLASS(NEW_CLASS, SETUP_FUNCTION);
-    
+  AUTO_REGISTER_CLASS(NEW_CLASS);
+
+///////////////////////////////////////////////////////////////////////////////
+// five args
+///////////////////////////////////////////////////////////////////////////////
+#define REAL_NEW_WITH_ARG_ARG_ARG_ARG_ARG(NEW_CLASS, ONE_VAR_TYPE, ONE_PD_TYPE, TWO_VAR_TYPE, TWO_PD_TYPE, THREE_VAR_TYPE, THREE_PD_TYPE, FOUR_VAR_TYPE, FOUR_PD_TYPE, FIVE_VAR_TYPE, FIVE_PD_TYPE) \
+STATIC_CLASS t_class * NEW_CLASS ## _class;    	    	    	\
+static void* create_ ## NEW_CLASS (ONE_VAR_TYPE arg, TWO_VAR_TYPE argtwo, THREE_VAR_TYPE argthree, FOUR_VAR_TYPE argfour, FIVE_VAR_TYPE argfive) \
+{     	    	    	    	    	    	    	    	\
+  try{	    	    	    	    	    	    	    	\
+    Obj_header *obj = new (pd_new(NEW_CLASS ## _class),(void *)NULL) Obj_header; \
+    CPPExtern::m_holder = &obj->pd_obj;                         \
+    CPPExtern::m_holdname=(char*)#NEW_CLASS;                            \
+    obj->data = new NEW_CLASS(arg, argtwo, argthree, argfour, argfive);  \
+    CPPExtern::m_holder = NULL;                                 \
+    CPPExtern::m_holdname=NULL;                                 \
+    return(obj);                                                \
+  } catch (GemException e) {e.report(); return NULL;}           \
+}   	    	    	    	    	    	    	    	\
+extern "C" {	    	    	    	    	    	    	\
+void NEW_CLASS ## _setup()    	    	    	    	\
+{   	    	    	    	    	    	    	    	\
+  if(!checkGemVersion(GEM_VERSION_MAJOR, GEM_VERSION_MINOR)) { \
+    ::error("[%s] will not be available", #NEW_CLASS);	       \
+    return;}						       \
+    NEW_CLASS ## _class = class_new(                       \
+    	     	gensym(#NEW_CLASS), 	    	    	    	\
+    	    	(t_newmethod)create_ ## NEW_CLASS,	    	\
+    	    	(t_method)&NEW_CLASS::obj_freeCallback,         \
+    	     	sizeof(Obj_header), GEM_CLASSFLAGS,             \
+    	     	ONE_PD_TYPE, TWO_PD_TYPE, THREE_PD_TYPE, FOUR_PD_TYPE, FIVE_PD_TYPE,	\
+    	     	A_NULL);						\
+    SET_HELPSYMBOL(NEW_CLASS);				\
+    NEW_CLASS::real_obj_setupCallback(NEW_CLASS ## _class);	\
+ }									\
+}									\
+  AUTO_REGISTER_CLASS(NEW_CLASS);
+
 #endif	// for header file
