@@ -18,18 +18,12 @@ LOG
 #define INCLUDE_GEMGLUTIL_H_
 
 #include "Base/GemBase.h"
-
 #include "Base/GemExportDef.h"
-#ifndef __APPLE__
-#include <GL/gl.h>
-#else
-#include <OpenGL/gl.h>
-#endif
 
-
-GEM_EXTERN extern int           getGLdefine(char *name);
-GEM_EXTERN extern int           getGLdefine(t_symbol *name);
-GEM_EXTERN extern int           getGLdefine(t_atom *name);
+GEM_EXTERN extern GLenum		glReportError (void);
+GEM_EXTERN extern int           getGLdefine(const char *name);
+GEM_EXTERN extern int           getGLdefine(const t_symbol *name);
+GEM_EXTERN extern int           getGLdefine(const t_atom *name);
 GEM_EXTERN extern int           getGLbitfield(int argc, t_atom *argv);
 #endif  // for header file
 
