@@ -16,49 +16,56 @@
 //
 /////////////////////////////////////////////////////////
 
-#include "GemPixImageLoad.h"
+#include "Base/GemGL.h"
 
+#include "GemPixImageLoad.h"
 #include "m_pd.h"
 
 #ifdef __APPLE__
-#include <Carbon/carbon.h>
-#include <QuickTime/QuickTime.h>
-#include <OpenGL/gl.h>
-#include <OpenGL/glext.h>
-#include <string.h>
+# include <Carbon/Carbon.h>
+# include <QuickTime/QuickTime.h>
 #endif // __APPLE__
 
-#ifdef _WINDOWS
-#include <io.h>
+#ifdef __WIN32__
+# include <io.h>
 #else
-#include <unistd.h>
+# include <unistd.h>
 #endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <setjmp.h>
-
 #include <string.h>
 
 #ifndef __APPLE__
 extern "C"
 {
-#include "tiffio.h"
+#ifdef HAVE_LIBTIFF
+# include "tiffio.h"
+#endif
 
 #undef EXTERN
 
-#ifdef _WINDOWS
-#undef FAR
+#ifdef __WIN32__
+# undef FAR
 #endif
 
-#include "jpeglib.h"
+#ifdef HAVE_LIBJPEG
+# include "jpeglib.h"
+#endif
 }
 
-
 #include "sgiimage.h"
 #endif // __APPLE__
 
 #include "GemPixUtil.h"
 
+#ifdef HAVE_LIBMAGICKPLUSPLUS
+# include <Magick++.h>
+imageStruct *magickImage2mem(const char *filename);
+#endif
+
+
 #ifdef __APPLE__
 imageStruct *QTImage2mem(GraphicsImportComponent inImporter);
 OSStatus FSPathMakeFSSpec(
@@ -66,27 +73,14 @@ OSStatus FSPathMakeFSSpec(
 	FSSpec *spec,
 	Boolean *isDirectory);
 #else
+# ifdef HAVE_LIBTIFF
 imageStruct *tiffImage2mem(const char *filename);
+# endif
+# ifdef HAVE_LIBJPEG
 imageStruct *jpegImage2mem(const char *filename);
+# endif /* LIBJPEG */
 imageStruct *sgiImage2mem(const char *filename);
 
-
-/* this function gives us 32 byte aligned data, the cache line size
-   of  pentiums */
-
-unsigned char* img_allocate(int size)
-{
-  unsigned char* data;
-#if 0
-  unsigned char* pad;
-  pad = new unsigned char[size];
-  data = (unsigned char*) ((((unsigned int)pad)+31)& (~31));
-#else
-  data = new unsigned char [size];
-#endif
-
-  return data; 
-}
 #endif // __APPLE__
 
 /***************************************************************************
@@ -107,14 +101,14 @@ GEM_EXTERN imageStruct *image2mem(const char *filename)
 
 		err = ::FSPathMakeFSSpec( (UInt8*)filename, &spec, NULL);
 		if (err) {
-			error("GEM: Unable to find file: %#s", spec.name);
-                        error("GEM: Unable to find filename:%s", filename);
+			error("GemImageLoad: Unable to find file: %#s", spec.name);
+                        error("GemImageLoad: Unable to find filename:%s", filename);
 			error("parID : %d", spec.parID); 
 			return NULL;
 		}
 		err = ::GetGraphicsImporterForFile(&spec, &importer);
 		if (err) {
-			error("GEM: Unable to import an image: %#s", spec.name);
+			error("GemImageLoad: Unable to import an image: %#s", spec.name);
 			return NULL;
 		}
 	}
@@ -168,10 +162,10 @@ GEM_EXTERN imageStruct *image2mem(const char *filename)
 		char realName[256];
 		char *realResult;
 
-		int fd = open_via_path(".", filename, "", realName, &realResult, 256, 0);
+		int fd = open_via_path(".", filename, "", realName, &realResult, 256, 1);
 		if (fd < 0)
 		{
-			error("GEM: Unable to find file: %s", filename);
+			error("GemImageLoad: Unable to find file: %s", filename);
 			return(NULL);
 		}
 		else
@@ -179,29 +173,33 @@ GEM_EXTERN imageStruct *image2mem(const char *filename)
 			int res = close(fd);
 			if (res == -1)
 			{
-				int foo;
-				foo = 1;
+                verbose(1, "GemImageLoad: Unable to close file-handle %d for '%s'", fd, filename);
 			}
 		}
 
 		sprintf(newName, "%s/%s", realName, realResult);
 	}
 
-	
+# ifdef HAVE_LIBMAGICKPLUSPLUS
+	// try to load via ImageMagick
+	if ( (image_block = magickImage2mem(newName)) )
+			return(image_block);
+# endif
+
+#ifdef HAVE_LIBJPEG
 	// try to load in a JPEG file
 	if ( (image_block = jpegImage2mem(newName)) )
 			return(image_block);
-
+#endif
 	// try to load in an SGI file
 	if ( (image_block = sgiImage2mem(newName)) )
 			return(image_block);
-
+#ifdef HAVE_LIBTIFF
 	// try to load in a TIFF file
 	if ( (image_block = tiffImage2mem(newName)) )
 			return(image_block);
-
+#endif
 	// unable to load image
-	error("GEM: Unable to load image: %s", newName);
 	return(NULL);
 }
 #endif // __APPLE__
@@ -223,41 +221,46 @@ imageStruct *QTImage2mem(GraphicsImportComponent inImporter)
 	imageStruct *image_block = new imageStruct;
 	image_block->xsize	= (*imageDescH)->width;
 	image_block->ysize	= (*imageDescH)->height;
-	//image_block->type	= GL_UNSIGNED_BYTE;
-        image_block->type	= GL_UNSIGNED_INT_8_8_8_8_REV;
-        //image_block->type	= GL_UNSIGNED_INT_8_8_8_8;
+
+        OSType pixelformat = 0;
+
+       /* afaik, there is no 8bit grayscale format....
+        * and even if it was, k8GrayPixelFormat would not be a define...
+        */
+#ifdef k8GrayPixelFormat
+       /* from the docs on "depth": what depth is this data (1-32) or ( 33-40 grayscale ) */
 	if ((*imageDescH)->depth <= 32) {
-		image_block->csize = 4;
-		//image_block->format = GL_RGBA;
-                image_block->format = GL_BGRA_EXT;
+	    image_block->setCsizeByFormat(GL_RGBA_GEM);
+            pixelformat = k32ARGBPixelFormat;
 	} else {
-		image_block->csize = 1;
-		image_block->format = GL_LUMINANCE;
+	    image_block->setCsizeByFormat(GL_LUMINANCE);
+            pixelformat = k8GrayPixelFormat;
 	}
+#else
+	image_block->setCsizeByFormat(GL_RGBA_GEM);
+        pixelformat = k32ARGBPixelFormat;
+#endif
+
 	::DisposeHandle((Handle)imageDescH);
 	imageDescH = NULL;
-	const int dataSize = image_block->ysize * image_block->xsize * image_block->csize;
+  image_block->allocate();
 
-	image_block->data = new unsigned char[dataSize];
 #ifdef __DEBUG__
-	post("QTImage2mem() : allocate %d bytes", dataSize);
+	post("QTImage2mem() : allocate %d bytes", image_block->xsize*image_block->ysize*image_block->csize);
 #endif
         GWorldPtr	gw = NULL;
 
-	OSErr err = QTNewGWorldFromPtr(&gw, 
-                                    k32ARGBPixelFormat,
-                                    &r, NULL, NULL, 0,
-                                   // keepLocal,	
-                                    //useDistantHdwrMem, 
-                                    image_block->data, 
-                                    (long)(image_block->xsize * image_block->csize));
+	OSErr err = QTNewGWorldFromPtr(&gw,
+                                 /* taken from pix_filmDarwin */
+                                 pixelformat,	// gives noErr
+                                 &r, NULL, NULL, 0,
+                                 // keepLocal,	
+                                 //useDistantHdwrMem, 
+                                 image_block->data, 
+                                 (long)(image_block->xsize * image_block->csize));
 	if (image_block->data == NULL || err) {
 		error("Can't allocate memory for an image.");
 	}
-	//image_block->pixelFormat = k32RGBAPixelFormat;
-        //image_block->pixelFormat = k32ARGBPixelFormat;
-	//image_block->pixMapH = GetGWorldPixMap(image_block->gw);
-	//::LockPixels(image_block->pixMapH);
 	::GraphicsImportSetGWorld(inImporter, gw, NULL);
 	::GraphicsImportDraw(inImporter);
         ::DisposeGWorld(gw);			//dispose the offscreen
@@ -266,6 +269,7 @@ imageStruct *QTImage2mem(GraphicsImportComponent inImporter)
 	return image_block;
 }
 #else
+# ifdef HAVE_LIBTIFF
 /***************************************************************************
  *
  * Read in a TIFF image.
@@ -323,7 +327,7 @@ imageStruct *tiffImage2mem(const char *filename)
 	    unsigned char *buf = new unsigned char [TIFFScanlineSize(tif)];
 	    if (buf == NULL)
 		{
-			error("GEM: can't allocate memory for scanline buffer: %s", filename);
+			error("GemImageLoad(TIFF): can't allocate memory for scanline buffer: %s", filename);
 		    TIFFClose(tif);
 			delete image_block;
 			return(NULL);
@@ -338,7 +342,7 @@ imageStruct *tiffImage2mem(const char *filename)
     		unsigned char *pixels = dstLine;
 			if (TIFFReadScanline(tif, buf, row, 0) < 0)
 			{
-			    error("GEM: bad image data read on line: %d: %s", row, filename);
+			    error("GemImageLoad(TIFF): bad image data read on line: %d: %s", row, filename);
 			    TIFFClose(tif);
 				delete image_block;
 				delete [] buf;
@@ -387,7 +391,7 @@ imageStruct *tiffImage2mem(const char *filename)
 		TIFFRGBAImage img;
 		if (TIFFRGBAImageBegin(&img, tif, 0, emsg) == 0)
 		{
-	        error("GEM: Error reading in image file: %s : %s", filename, emsg);
+	        //error("GemImageLoad(TIFF): Error reading in image file: %s : %s", filename, emsg);
 			delete image_block;
 	        TIFFClose(tif);
 	        return(NULL);
@@ -396,7 +400,7 @@ imageStruct *tiffImage2mem(const char *filename)
 		uint32 *raster = (uint32 *) _TIFFmalloc(npixels * sizeof(uint32));
 		if (raster == NULL)
 		{
-			error("GEM: Unable to allocate memory for image: %s", filename);
+			error("GemImageLoad(TIFF): Unable to allocate memory for image: %s", filename);
 			TIFFClose(tif);
 			delete image_block;
 			return(NULL);
@@ -404,7 +408,7 @@ imageStruct *tiffImage2mem(const char *filename)
 
 		if (TIFFRGBAImageGet(&img, raster, width, height) == 0)
 		{
-			error("GEM: Error getting image data in file: %s, %s", filename, emsg);
+			//error("GemImageLoad(TIFF): Error getting image data in file: %s, %s", filename, emsg);
 			_TIFFfree(raster);
 			TIFFClose(tif);
 			delete image_block;
@@ -442,7 +446,8 @@ imageStruct *tiffImage2mem(const char *filename)
 
     return(image_block);
 }
-
+# endif /* HAVE_LIBTIFF */
+# ifdef HAVE_LIBJPEG
 /***************************************************************************
  *
  * Read in a JPEG image.
@@ -490,7 +495,7 @@ imageStruct *jpegImage2mem(const char *filename)
 	FILE * infile;
 	if ((infile = fopen(filename, "rb")) == NULL)
 	{
-	    error("GEM: Unable to open image file: %s", filename);
+	    //error("GemImageLoad(JPEG): Unable to open image file: %s", filename);
 	    return(NULL);
 	}
 
@@ -609,7 +614,7 @@ imageStruct *jpegImage2mem(const char *filename)
 
 	return(image_block);
 }
-
+# endif /* HAVE_LIBJPEG */
 /***************************************************************************
  *
  * Read in an SGI image.
@@ -639,7 +644,7 @@ imageStruct *sgiImage2mem(const char *filename)
 	}
 	else
 	{
-		error("GEM: unknown color components in SGI file: %s", filename);
+		//error("GemImageLoad(SGI): unknown color components in SGI file: %s", filename);
 		delete image_block;
 		return(NULL);
 	}
@@ -647,13 +652,12 @@ imageStruct *sgiImage2mem(const char *filename)
 	unsigned int32 *readData = longimagedata((char *)filename);
 	if (!readData)
 	{
-		error("GEM: error reading SGI image file: %s", filename);
+		//error("GemImageLoad: error reading SGI image file: %s", filename);
 		delete image_block;
 		return(NULL);
 	}
 
-	const int dataSize = image_block->ysize * image_block->xsize * image_block->csize;
-	image_block->allocate(dataSize);
+	image_block->allocate();
 	unsigned char *src = (unsigned char *)readData;
 	unsigned char *dst = &(image_block->data[0]);
     const int yStride = image_block->xsize * image_block->csize;
@@ -719,3 +723,28 @@ imageStruct *sgiImage2mem(const char *filename)
 }
 #endif //__APPLE__
 
+#ifdef HAVE_LIBMAGICKPLUSPLUS
+imageStruct *magickImage2mem(const char *filename){
+  imageStruct *image_block = new imageStruct;
+  Magick::Image image;
+  try {
+    // Read a file into image object
+    image.read( filename );
+    image.flip();
+
+    image_block->xsize=(GLint)image.columns();
+    image_block->ysize=(GLint)image.rows();
+    image_block->setCsizeByFormat(GL_RGBA);
+    image_block->reallocate();
+
+    image.write(0,0,image_block->xsize,image_block->ysize,
+		"RGBA",
+		Magick::CharPixel,
+		(void*)(image_block->data));
+  }catch( Magick::Exception e )  {
+    return NULL;
+  }
+  return image_block;
+}
+
+#endif
