@@ -14,12 +14,13 @@
 /////////////////////////////////////////////////////////
 
 #ifdef __APPLE__
-
+#include "Base/GemGL.h"
 #include <Carbon/Carbon.h>
+#include <QuickTime/QuickTime.h>
 #include "GemWinCreate.h"
+#include "Base/GemBase.h"
 #include "GemMan.h"
 #include "GemEvent.h"
-#include "m_pd.h"
 
 #define PIXEL_SIZE	32		// 16 or 32
 #define DEPTH_SIZE	16
@@ -60,6 +61,9 @@ struct structGLWindowInfo // storage for setup info
 typedef struct structGLWindowInfo structGLWindowInfo;
 typedef struct structGLWindowInfo * pstructGLWindowInfo;
 
+// the master context associated with no window and shared by all other contexts
+AGLContext masterContext = NULL;
+
 // globals (internal/private) -----------------------------------------------
 
 const RGBColor		rgbBlack = { 0x0000, 0x0000, 0x0000 };
@@ -68,22 +72,17 @@ const short kWindowType = kWindowDocumentProc;
 
 // GL stuff
 Boolean gfHasPackedPixels = false;
-//structGLInfo		glInfo;
 structGLWindowInfo	glWInfo;
 AGLDrawable 		gaglDraw = NULL;
-//Rect 			grectWin;
-AGLContext 		gaglContext = 0;
-GLuint 			gFontList = 0;
-char 			gInfoString [512] = "";
-static bool 		haveContext = false;
+AGLContext			gaglContext = 0;
+GLuint				gFontList = 0;
+char				gInfoString [512] = "";
 
 EventHandlerUPP		gEvtHandler;
 EventHandlerRef		ref;
 ProcessSerialNumber	psn = {0, kCurrentProcess };
 static pascal OSStatus evtHandler(EventHandlerCallRef myHandler, EventRef event, void* userData);
 
-void SetContextValid (bool val);
-bool HaveValidContext (void);
 AGLContext SetupAGLFullScreen (GDHandle display, short * pWidth, short * pHeight);
 
 // Prototypes
@@ -107,18 +106,17 @@ AGLContext SetupAGLFullScreen (GDHandle display, short * pWidth, short * pHeight
 // Note: Errors can be generated internally when a specific device fails, this is normal and these
 //		  will not be returned is a subsequent device succeeds
 
-OSStatus BuildGL (AGLDrawable* paglDraw, AGLContext* paglContext, //DSpContextReference* pdspContext, 
+OSStatus BuildGL (AGLDrawable* paglDraw, AGLContext* paglContext,
 				  short* pnumDevice, pstructGLInfo pcontextInfo, AGLContext aglShareContext);
                                   
-static OSStatus BuildGLonDevice (AGLDrawable* paglDraw, AGLContext* paglContext, //DSpContextReference* pdspContext, 
+static OSStatus BuildGLonDevice (AGLDrawable* paglDraw, AGLContext* paglContext, 
 				  		  GDHandle hGD, pstructGLInfo pcontextInfo, AGLContext aglShareContext);
 
-static OSStatus BuildGLonWindow (WindowPtr pWindow, AGLContext* paglContext, pstructGLWindowInfo pcontextInfo, AGLContext aglShareContext);
 static OSStatus BuildDrawable (AGLDrawable* paglDraw, GDHandle hGD, pstructGLInfo pcontextInfo);
 
-static OSStatus BuildGLContext (AGLDrawable* paglDraw, AGLContext* paglContext, /*DSpContextReference* pdspContext,*/ GDHandle hGD, 
+static OSStatus BuildGLContext (AGLDrawable* paglDraw, AGLContext* paglContext, GDHandle hGD, 
 								pstructGLInfo pcontextInfo, AGLContext aglShareContext);
-static void DumpCurrent (AGLDrawable* paglDraw, AGLContext* paglContext, /*DSpContextReference* pdspContext,*/ pstructGLInfo pcontextInfo);
+static void DumpCurrent (AGLDrawable* paglDraw, AGLContext* paglContext, pstructGLInfo pcontextInfo);
 static Boolean CheckRenderer (GDHandle hGD, long *VRAM, long *textureRAM, GLint* pDepthSizeSupport, Boolean fAccelMust);
 static Boolean CheckAllDeviceRenderers (long* pVRAM, long* pTextureRAM, GLint* pDepthSizeSupport, Boolean fAccelMust);
 static Boolean CheckWindowExtents (GDHandle hGD, short width, short height);
@@ -126,7 +124,7 @@ static Boolean CheckWindowExtents (GDHandle hGD, short width, short height);
 // Destroys drawable and context
 // Ouputs: *paglDraw, *paglContext and *pdspContext should be 0 on exit
 
-OSStatus DestroyGL (AGLDrawable* paglDraw, AGLContext* paglContext, /*DSpContextReference* pdspContext,*/ pstructGLInfo pcontextInfo);
+OSStatus DestroyGL (AGLDrawable* paglDraw, AGLContext* paglContext, pstructGLInfo pcontextInfo);
 
 // same as above except that it takes a window as input and attempts to build requested conext on that
 OSStatus BuildGLFromWindow (WindowPtr pWindow, AGLContext* paglContext, pstructGLWindowInfo pcontextInfo, AGLContext aglShareContext);
@@ -137,9 +135,6 @@ OSStatus DestroyGLFromWindow (AGLContext* paglContext, pstructGLWindowInfo pcont
 // Handle reporting of agl errors, error code is passed through
 OSStatus aglReportError (void);
 
-// Handle reporting of OpenGL errors, error code is passed through
-OSStatus glReportError (void);
-
 // Runtime check to see if we are running on Mac OS X
 // Inputs:  None
 // Returns: 0 if < Mac OS X or version number of Mac OS X (10.0 for GM)
@@ -171,8 +166,9 @@ GEM_EXTERN int createGemWindow(WindowInfo &info, WindowHints &hints)
 #ifdef DEBUG
     post("MAC: createGemWindow()");
 #endif
-    EventTypeSpec	list[] = {		{ kEventClassWindow, kEventWindowActivated },
-                                    { kEventClassWindow, kEventWindowClose },
+    EventTypeSpec	list[] = {		//{ kEventClassWindow, kEventWindowActivated },
+									//{ kEventClassWindow, kEventWindowGetClickActivation },
+                                    { kEventClassWindow, kEventWindowClosed },
                                     { kEventClassMouse, kEventMouseDown },
                                     { kEventClassMouse, kEventMouseUp },
                                     { kEventClassMouse, kEventMouseMoved },
@@ -228,7 +224,9 @@ GEM_EXTERN int createGemWindow(WindowInfo &info, WindowHints &hints)
 
         for (i=0; i < (int)newDspyCnt; i++){
             CGRect displayRect = CGDisplayBounds (activeDspys[i]);
-            post("GemWinCreateMac: display %d width %d height %d origin.x %d origin.y %d", i, (long)displayRect.size.width, (long)displayRect.size.height, (long)displayRect.origin.x, (long)displayRect.origin.y);
+            post("GemWinCreateMac: display %d width %d height %d origin.x %d origin.y %d", i, 
+				(long)displayRect.size.width, (long)displayRect.size.height,
+				(long)displayRect.origin.x, (long)displayRect.origin.y);
         }
         
         post("GemWinCreateMac: attempting fullscreen on display %d",hints.fullscreen-1);
@@ -343,6 +341,10 @@ GEM_EXTERN int createGemWindow(WindowInfo &info, WindowHints &hints)
         
     }//end of conditional for fullscreen vs windowed
     
+		ProcessSerialNumber psn;
+		GetCurrentProcess(&psn);
+		TransformProcessType(&psn, kProcessTransformToForegroundApplication);
+		
         gEvtHandler = NewEventHandlerUPP( evtHandler );
         InstallEventHandler( GetApplicationEventTarget(), gEvtHandler,
                                         GetEventTypeCount( list ), list,
@@ -358,8 +360,21 @@ GEM_EXTERN int createGemWindow(WindowInfo &info, WindowHints &hints)
         glWInfo.aglAttributes [i++] = AGL_RGBA;
         glWInfo.aglAttributes [i++] = AGL_PIXEL_SIZE;
         glWInfo.aglAttributes [i++] = 32;
-        glWInfo.aglAttributes [i++] = AGL_DEPTH_SIZE;
-        glWInfo.aglAttributes [i++] = 16;
+        glWInfo.aglAttributes [i++] = AGL_DEPTH_SIZE; // 0, 16, 24, or 32
+        glWInfo.aglAttributes [i++] = 24;
+//		glWInfo.aglAttributes [i++] = AGL_AUX_BUFFERS;
+//		glWInfo.aglAttributes [i++] = 3;
+		glWInfo.aglAttributes [i++] = AGL_STENCIL_SIZE; // 0 or 8
+		glWInfo.aglAttributes [i++] = 8;
+/*		glWInfo.aglAttributes [i++] = AGL_ACCUM_RED_SIZE; // 8 or 16
+		glWInfo.aglAttributes [i++] = 8;
+		glWInfo.aglAttributes [i++] = AGL_ACCUM_GREEN_SIZE;
+		glWInfo.aglAttributes [i++] = 8;
+		glWInfo.aglAttributes [i++] = AGL_ACCUM_BLUE_SIZE;
+		glWInfo.aglAttributes [i++] = 8;
+		glWInfo.aglAttributes [i++] = AGL_ACCUM_ALPHA_SIZE;
+		glWInfo.aglAttributes [i++] = 8;
+*/
         if (hints.buffer == 2){
             glWInfo.aglAttributes [i++] = AGL_DOUBLEBUFFER;
         }
@@ -374,19 +389,25 @@ GEM_EXTERN int createGemWindow(WindowInfo &info, WindowHints &hints)
         glWInfo.aglAttributes [i++] = AGL_ACCELERATED;
         glWInfo.aglAttributes [i++] = AGL_NO_RECOVERY; 	// should be used whenever packed pixels is used to 
                                                         //	disable software back up textures
+/*		glWInfo.aglAttributes [i++] = AGL_RENDERER_ID;
+		glWInfo.aglAttributes [i++] = 0x00020400; // AGL_RENDERER_GENERIC_FLOAT_ID;
+		glWInfo.aglAttributes [i++] = AGL_DOUBLEBUFFER;
+		glWInfo.aglAttributes [i++] = AGL_DEPTH_SIZE;
+		glWInfo.aglAttributes [i++] = 24;
+*/
         glWInfo.aglAttributes [i++] = AGL_NONE;
 /*        
         info.pWind = ::GetWindowFromPort(gaglDraw);
         BuildGLFromWindow (GetWindowFromPort(gaglDraw), &info.context, &glWInfo, hints.shared);
 */        
         BuildGLFromWindow ( info.pWind, &info.context, &glWInfo, hints.shared);
+//		AGL_MACRO_DECLARE_VARIABLES()
    // }// end of window creation on main device - this is the old fullscreen code
     
     if (!info.context){
         post("MAC:  no info.context");
         return (0);
     }
-    SetContextValid (true);
     hints.real_w = hints.width;
     hints.real_h = hints.height;
     info.fs = 0;//hints.fullscreen;
@@ -471,6 +492,13 @@ int cursorGemWindow(WindowInfo &info, int state)
 
   return state;
 }
+
+
+int topmostGemWindow(WindowInfo &info, int state){
+  /* we don't give a warning to not be annoying */
+  return 1;
+}
+
 //-----------------------------------------------------------------------------------------------------------------------
 // SetupAGLFullScreen, for 2nd monitor
 //-----------------------------------------------------------------------------------------------------------------------
@@ -544,7 +572,7 @@ AGLContext SetupAGLFullScreen (GDHandle display, short * pWidth, short * pHeight
 
 // if fail to allocate: paglContext will be NULL
 // if error: will return error and paglContext will be NULL
-
+/*
 OSStatus BuildGLFromWindow (WindowPtr pWindow, AGLContext* paglContext, pstructGLWindowInfo pcontextInfo, AGLContext aglShareContext)
 {
     if (!pWindow){
@@ -552,6 +580,7 @@ OSStatus BuildGLFromWindow (WindowPtr pWindow, AGLContext* paglContext, pstructG
     }
     return BuildGLonWindow (pWindow, paglContext, pcontextInfo, aglShareContext);
 }
+*/
 // --------------------------------------------------------------------------
 
 // BuildGLonDrawable
@@ -566,8 +595,8 @@ OSStatus BuildGLFromWindow (WindowPtr pWindow, AGLContext* paglContext, pstructG
 
 // if fail to allocate: paglContext will be NULL
 // if error: will return error and paglContext will be NULL
-
-static OSStatus BuildGLonWindow (WindowPtr pWindow, AGLContext* paglContext, pstructGLWindowInfo pcontextInfo, AGLContext aglShareContext)
+//static
+OSStatus BuildGLFromWindow (WindowPtr pWindow, AGLContext* paglContext, pstructGLWindowInfo pcontextInfo, AGLContext aglShareContext)
 {
     GDHandle hGD = NULL;
     GrafPtr cgrafSave = NULL;
@@ -588,7 +617,7 @@ static OSStatus BuildGLonWindow (WindowPtr pWindow, AGLContext* paglContext, pst
     GetPort (&cgrafSave);
     SetPortWindowPort(pWindow);
 
-    // check renderere VRAM and acceleration
+    // check renderer VRAM and acceleration
     numDevices = FindGDHandleFromWindow (pWindow, &hGD);
     if (!pcontextInfo->fDraggable) 	// if numDevices > 1 then we will only be using the software renderer otherwise check only window device
     {
@@ -605,11 +634,14 @@ static OSStatus BuildGLonWindow (WindowPtr pWindow, AGLContext* paglContext, pst
             if (pcontextInfo->fAcceleratedMust)
             {
 #ifdef DEBUG
-                post("MAC: BuildGLonWindow: Unable to accelerate window that spans multiple devices");
+                post("MAC: BuildGLonWindow: trying to accelerate window that spans multiple devices");
 #endif
-                return err;
+
+             //   return err;
+
+
             }
-        }
+        } 
         else // not draggable on single device
         {
 #ifdef DEBUG
@@ -958,7 +990,7 @@ static Boolean CheckRenderer (GDHandle hGD, long* pVRAM, long* pTextureRAM, GLin
 	aglReportError ();
 	if(!head_info)
 	{
-		post("aglQueryRendererInfo error");
+		error("aglQueryRendererInfo error");
 		return false;
 	}
 	else
@@ -1043,7 +1075,7 @@ static Boolean CheckAllDeviceRenderers (long* pVRAM, long* pTextureRAM, GLint* p
         aglReportError ();
         if(!head_info)
         {
-            post("aglQueryRendererInfo error");
+            error("aglQueryRendererInfo error");
             return false;
         }
         else
@@ -1126,7 +1158,7 @@ static Boolean CheckWindowExtents (GDHandle hGD, short width, short height)
 	short deviceWidth = (short) ((**hGD).gdRect.right - (**hGD).gdRect.left);
 	short windowWidthExtra, windowHeightExtra;
 	// build window (not visible)
-	WindowPtr pWindow = NewCWindow (NULL, &rectWin, "\p", true, kWindowType, (WindowPtr)-1, 0, 0);
+	WindowPtr pWindow = NewCWindow (NULL, &rectWin, (const unsigned char*)"\p", true, kWindowType, (WindowPtr)-1, 0, 0);
 	
 	GetWindowBounds (pWindow, kWindowStructureRgn, &strucRect);
 
@@ -1145,7 +1177,7 @@ static Boolean CheckWindowExtents (GDHandle hGD, short width, short height)
 // Builds OpenGL context
 
 // Inputs: 	hGD: GDHandle to device to look at
-//			pcontextInfo: request and requirements for cotext and drawable
+//			pcontextInfo: request and requirements for context and drawable
 
 // Outputs: paglContext as allocated
 //			pcontextInfo:  allocated parameters
@@ -1153,11 +1185,10 @@ static Boolean CheckWindowExtents (GDHandle hGD, short width, short height)
 // if fail to allocate: paglContext will be NULL
 // if error: will return error paglContext will be NULL
 
-static OSStatus BuildGLContext (AGLDrawable* paglDraw, AGLContext* paglContext, //DSpContextReference* pdspContext,
+static OSStatus BuildGLContext (AGLDrawable* paglDraw, AGLContext* paglContext,
 							  GDHandle hGD, pstructGLInfo pcontextInfo, AGLContext aglShareContext)
 {
 	OSStatus err = noErr;
-	//NumVersion versionDSp = GetDSpVersion ();
 
 	if ((Ptr) kUnresolvedCFragSymbolAddress == (Ptr) aglChoosePixelFormat) // check for existance of OpenGL
 	{
@@ -1166,7 +1197,7 @@ static OSStatus BuildGLContext (AGLDrawable* paglDraw, AGLContext* paglContext,
 	}	
 	
 	// DSp has problems on Mac OS X with DSp version less than 1.99 so use agl full screen
-	if ((pcontextInfo->fFullscreen) && (CheckMacOSX ()) /*&& ((versionDSp.majorRev == 0x01) && (versionDSp.minorAndBugRev < 0x99))*/) // need to set pixel format for full screen
+	if ((pcontextInfo->fFullscreen) && (CheckMacOSX ()) ) // need to set pixel format for full screen
 	{
 		short i = 0;
 		while (pcontextInfo->aglAttributes[i++] != AGL_NONE) {}
@@ -1189,7 +1220,7 @@ static OSStatus BuildGLContext (AGLDrawable* paglDraw, AGLContext* paglContext,
 	*paglContext = aglCreateContext (pcontextInfo->fmt, aglShareContext);		
         // Create an AGL context
  	if (AGL_BAD_MATCH == aglGetError())
-		*paglContext = aglCreateContext (pcontextInfo->fmt, 0); // unable to sahre context, create without sharing
+		*paglContext = aglCreateContext (pcontextInfo->fmt, 0); // unable to share context, create without sharing
 	aglReportError ();
 	if (NULL == *paglContext) 
 	{
@@ -1200,7 +1231,7 @@ static OSStatus BuildGLContext (AGLDrawable* paglDraw, AGLContext* paglContext,
 		aglShareContext = *paglContext;
 	
 	// set our drawable
-        // not Mac OS X fullscreen:  this is for three cases 1) Mac OS 9 windowed 2) Mac OS X windowed 3) Mac OS 9 fullscreen (as you need to build a window on top of DSp for GL to work correctly
+	// not Mac OS X fullscreen:  this is for three cases 1) Mac OS 9 windowed 2) Mac OS X windowed 3) Mac OS 9 fullscreen (as you need to build a window on top of DSp for GL to work correctly
 	{
 		// build window as late as possible
 		err = BuildDrawable (paglDraw, hGD, pcontextInfo);
@@ -1214,7 +1245,13 @@ static OSStatus BuildGLContext (AGLDrawable* paglDraw, AGLContext* paglContext,
 	}
 	if(!aglSetCurrentContext (*paglContext))			// make the context the current context
 		return aglReportError ();
-	
+		
+	// set swap interval to sync with vbl
+	/*
+	GLint	swapinterval = 1;
+	if (!aglSetInteger(*paglContext, AGL_SWAP_INTERVAL, &swapinterval))
+		return aglReportError();
+		*/
 	return err;
 }
 /////////////////////////////////////////////////////////////////////////////
@@ -1327,9 +1364,9 @@ static OSStatus BuildDrawable (AGLDrawable* paglDraw, GDHandle hGD, pstructGLInf
 	rectWin.bottom = (short) (rectWin.top + pcontextInfo->height);
 	
 	if (pcontextInfo->fFullscreen)
-		*paglDraw = GetWindowPort (NewCWindow (NULL, &rectWin, "\p", 0, plainDBox, (WindowPtr)-1, 0, 0));
+		*paglDraw = GetWindowPort (NewCWindow (NULL, &rectWin, (const unsigned char*)"\p", 0, plainDBox, (WindowPtr)-1, 0, 0));
 	else
-		*paglDraw = GetWindowPort (NewCWindow (NULL, &rectWin, "\p", 0, kWindowType, (WindowPtr)-1, 0, 0));
+		*paglDraw = GetWindowPort (NewCWindow (NULL, &rectWin, (const unsigned char*)"\p", 0, kWindowType, (WindowPtr)-1, 0, 0));
 		ShowWindow (GetWindowFromPort (*paglDraw));
 
 	GetPort (&pGrafSave);
@@ -1360,19 +1397,6 @@ OSStatus aglReportError (void)
 		return (OSStatus) err;
 }
 
-void SetContextValid (bool val)
-{
-	haveContext = val;
-}
-
-bool HaveValidContext (void)
-{
-	if (haveContext)
-		return true;
-	else
-		return false;
-}
-
 static pascal OSStatus evtHandler (EventHandlerCallRef myHandler, EventRef event, void* userData)
 {
     OSStatus result = eventNotHandledErr;
@@ -1403,13 +1427,20 @@ static pascal OSStatus evtHandler (EventHandlerCallRef myHandler, EventRef event
             case kEventClassWindow:
                 switch (kind)
                 {
-                    case kEventWindowActivated:
+/*                    case kEventWindowActivated:
                         GetEventParameter( event, kEventParamDirectObject, typeWindowRef, NULL, sizeof(WindowRef), NULL, &winRef);
                         SelectWindow(winRef);
                         result = noErr;
                         break;
+                    case kEventWindowGetClickActivation:
+                        GetEventParameter( event, kEventParamDirectObject, typeWindowRef, NULL, sizeof(WindowRef), NULL, &winRef);
+                        SelectWindow(winRef);
+                        result = noErr;
+                        break;
+						*/
                     case kEventWindowClosed:
-                        //destroyGemWindow(
+                        //destroyGemWindow()
+						GemMan::destroyWindowSoon();
                         break;
                 }
                 break;
@@ -1490,4 +1521,82 @@ static pascal OSStatus evtHandler (EventHandlerCallRef myHandler, EventRef event
     }
     return result;
 }
+
+void gemWinSwapBuffers(WindowInfo&nfo)
+{
+  ::aglSwapBuffers(nfo.context);
+}
+
+void gemWinMakeCurrent(WindowInfo&nfo) 
+{
+  ::aglSetDrawable( nfo.context, GetWindowPort(nfo.pWind) );
+  ::aglSetCurrentContext(nfo.context);
+}
+
+bool initGemWin(void) {
+  // Check QuickTime installed
+  long	QDfeature;
+  if (OSErr err = ::Gestalt(gestaltQuickTime, &QDfeature)) {
+    error("GEM: QuickTime is not installed : %d", err);
+    return 0;
+  } else {
+    if (OSErr err = ::EnterMovies()) {
+      error("GEM: Couldn't initialize QuickTime : %d", err);
+      return 0;
+    }
+  }
+  // check existence of OpenGL libraries
+  if ((Ptr)kUnresolvedCFragSymbolAddress == (Ptr)aglChoosePixelFormat) {
+    error("GEM: OpenGL is not installed");
+    return 0;
+  }
+  // This is to create a "master context" on Gem initialization, with
+  //  the hope that we can then share it with later context's created
+  //  when opening new rendering windows, and thereby share resources
+  //  - no window will be directly associate with this context!
+  //  - should remove the need for GemMan::HaveValidContext()
+  GLint attrib[] = {AGL_RGBA, AGL_DOUBLEBUFFER, AGL_NO_RECOVERY, AGL_NONE};
+  
+  //  GDHandle display = GetMainDevice();
+  //  AGLPixelFormat aglPixFmt = aglChoosePixelFormat( &display, 1, attrib );
+  AGLPixelFormat aglPixFmt = aglChoosePixelFormat( NULL, 0, attrib );
+	GLenum err = aglGetError();
+	if (AGL_NO_ERROR != err)
+		post((char *)aglErrorString(err));
+  masterContext = aglCreateContext( aglPixFmt, NULL );
+	err = aglGetError();
+	if (AGL_NO_ERROR != err)
+		post((char *)aglErrorString(err));
+  aglSetCurrentContext( masterContext);
+  
+  //  AGL_MACRO_DECLARE_VARIABLES()
+
+  aglDestroyPixelFormat( aglPixFmt );
+
+  return 1;
+}
+
+GEM_EXTERN void initWin_sharedContext(WindowInfo &info, WindowHints &hints)
+{
+  //  myHints.shared = constInfo.context;
+  info.context = masterContext;
+  hints.shared = masterContext;
+}
+
+
+GEM_EXTERN void dispatchGemWindowMessages(WindowInfo &win)
+{
+  EventRef	theEvent;
+  EventTargetRef theTarget;
+    
+  theTarget = GetEventDispatcherTarget();
+  // TODO:
+  //   this only gets one event per frame, so there's gotta be a better way, right?
+  ReceiveNextEvent( 0, NULL, kEventDurationNoWait, true, &theEvent );
+  {
+    SendEventToEventTarget( theEvent, theTarget);
+    ReleaseEvent( theEvent );
+  }
+}
+
 #endif
