@@ -1,3 +1,7 @@
+#include "Base/config.h"
+#ifdef HAVE_LIBGLEW
+# include <GL/glxew.h>
+#else
 /*
 ** The OpenGL Extension Wrangler Library
 ** Copyright (C) 2002-2008, Milan Ikits <milan ikits[]ieee org>
@@ -1395,3 +1399,4 @@ extern GLboolean glxewGetExtension (const char* name);
 #endif
 
 #endif /* __glxew_h__ */
+#endif /* HAVE_LIBGLEW */
