@@ -20,7 +20,7 @@
 
 #include "Base/GemState.h"
 
-const int circle::NUM_PNTS = 100;
+#define NUM_PNTS 100
 GLfloat *circle::m_cos = NULL;
 GLfloat *circle::m_sin = NULL;
 
@@ -48,19 +48,25 @@ circle :: ~circle()
 { }
 
 /////////////////////////////////////////////////////////
-// render
+// renderShape
 //
 /////////////////////////////////////////////////////////
-void circle :: render(GemState *state)
+void circle :: renderShape(GemState *state)
 {
+  if(m_drawType==GL_DEFAULT_GEM)m_drawType=GL_POLYGON;
     glNormal3f(0.0f, 0.0f, 1.0f);
     glLineWidth(m_linewidth);
     glBegin(m_drawType);
 	    if (state->texture)
 	    {
-	      GLfloat xsize  = state->texCoords[1].s;
-	      GLfloat ysize0 = state->texCoords[2].t;
-	      GLfloat ysize  = state->texCoords[1].t;
+	      GLfloat xsize  = 1.f;
+	      GLfloat ysize0 = 0.f;
+	      GLfloat ysize  = 1.f;
+	      if(state->numTexCoords>=3){
+		xsize  = state->texCoords[1].s;
+		ysize0 = state->texCoords[2].t;
+		ysize  = state->texCoords[1].t;
+	      }
 	        for (int n = 0; n < NUM_PNTS; n++)
 	        {
 		  glTexCoord2f(xsize*(m_cos[n] + 1) / 2.f, (ysize0-ysize)*(m_sin[n] + 1) / 2.f+ysize);
