@@ -47,12 +47,8 @@ class GEM_EXTERN circle : public GemShape
         virtual ~circle();
 
         //////////
-        // Do the rendering
-        virtual void 	render(GemState *state);
-
-        //////////
-        // number of points in the lookup table
-        static const int NUM_PNTS;
+        // Do the renderShapeing
+        virtual void 	renderShape(GemState *state);
 
         //////////
         // cos lookup table
