@@ -48,15 +48,8 @@ class GEM_EXTERN cube : public GemShape
     	virtual ~cube();
 
     	//////////
-    	// Do the rendering
-    	virtual void 	render(GemState *state);
-	
-	int	m_blend;
-	
-    private:
-    //////////
-    // Static member functions
-    static void 	blendMessCallback(void *data, t_floatarg size);
+    	// Do the renderShapeing
+    	virtual void 	renderShape(GemState *state);
 };
 
 #endif	// for header file
