@@ -22,10 +22,6 @@
 #include "Base/GemFuncUtil.h"
 #include <string.h>
 
-const int curve3d::NUM_PNTS_MAX = 200; // nb max de points a l'affichage
-const int curve3d::NUM_PNTS_CONTROL_MAX = 50; // nb max de points de controle
-
-
 CPPEXTERN_NEW_WITH_TWO_ARGS(curve3d, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFLOAT)
 
 /////////////////////////////////////////////////////////
@@ -37,30 +33,32 @@ CPPEXTERN_NEW_WITH_TWO_ARGS(curve3d, t_floatarg, A_DEFFLOAT, t_floatarg, A_DEFFL
 //
 /////////////////////////////////////////////////////////
 curve3d :: curve3d(t_floatarg sizeX,t_floatarg sizeY )
-  : GemShape(1)
+  : GemShape(1),
+    nb_pts_control_X(2), nb_pts_control_Y(2),
+    nb_pts_affich_X (30), nb_pts_affich_Y (30),
+    m_drawType(1),
+    m_posXYZ(NULL)
 {
   int i, j, a;
 
-  m_drawType = 1;
+  nb_pts_control_X = MAX(2, (int)sizeX);
+  nb_pts_control_Y = MAX(2, (int)sizeY);
 
-  nb_pts_control_X = (int)sizeX;
-  nb_pts_control_Y = (int)sizeY;
+  m_posXYZ = new t_float3[nb_pts_control_X*nb_pts_control_Y];
 
-  nb_pts_control_X = MIN (nb_pts_control_X,NUM_PNTS_CONTROL_MAX);
-  nb_pts_control_X = MAX (nb_pts_control_X,2);
-  nb_pts_control_Y = MIN (nb_pts_control_Y,NUM_PNTS_CONTROL_MAX);
-  nb_pts_control_Y = MAX (nb_pts_control_Y,2);
-
-  nb_pts_affich_X = 30;				// valeur par defaut
-  nb_pts_affich_Y = 30;
+  if(!m_posXYZ){
+    nb_pts_control_X=0;
+    nb_pts_control_Y=0;
+  }
 
   for (i=0; i < nb_pts_control_X; i++)
     for (j=0; j < nb_pts_control_Y; j++) {
       a= i + j * nb_pts_control_X;
-      posXYZ[a][0]= (float)i/nb_pts_control_X;
-      posXYZ[a][1]= (float)j/nb_pts_control_Y;
-      posXYZ[a][2]= 0.0;
+      m_posXYZ[a].x= (float)i/nb_pts_control_X;
+      m_posXYZ[a].y= (float)j/nb_pts_control_Y;
+      m_posXYZ[a].z= 0.0;
     }
+
 }
 
 //////////////////////////////////////////////////////////
@@ -68,7 +66,9 @@ curve3d :: curve3d(t_floatarg sizeX,t_floatarg sizeY )
 //
 /////////////////////////////////////////////////////////
 curve3d :: ~curve3d()
-{ }
+{ 
+  if(m_posXYZ)delete[]m_posXYZ;
+}
 
 //////////////////////////////////////////////////////////
 // setMess
@@ -76,9 +76,9 @@ curve3d :: ~curve3d()
 /////////////////////////////////////////////////////////
 void curve3d :: setMess(int X, int Y, float posX, float posY, float posZ){
   if ((X>=0)&(X<nb_pts_control_X)&(Y>=0)&(Y<nb_pts_control_Y))    {
-    posXYZ[X+Y*nb_pts_control_X][0]=posX;
-    posXYZ[X+Y*nb_pts_control_X][1]=posY;
-    posXYZ[X+Y*nb_pts_control_X][2]=posZ;
+    m_posXYZ[X+Y*nb_pts_control_X].x=posX;
+    m_posXYZ[X+Y*nb_pts_control_X].y=posY;
+    m_posXYZ[X+Y*nb_pts_control_X].z=posZ;
     setModified();
   }
 }
@@ -88,10 +88,25 @@ void curve3d :: setMess(int X, int Y, float posX, float posY, float posZ){
 //
 /////////////////////////////////////////////////////////
 void curve3d :: resolutionMess(int resolutionX, int resolutionY){
+  int x=0;
+  int y=0;
+
   nb_pts_control_X = (resolutionX < 2) ? 2 : resolutionX;
-  if (nb_pts_control_X > NUM_PNTS_CONTROL_MAX)  nb_pts_control_X = NUM_PNTS_CONTROL_MAX ;
   nb_pts_control_Y = (resolutionY < 2) ? 2 : resolutionY;
-  if (nb_pts_control_Y > NUM_PNTS_CONTROL_MAX)  nb_pts_control_Y = NUM_PNTS_CONTROL_MAX ;
+  if(m_posXYZ)delete[]m_posXYZ;
+  m_posXYZ = new t_float3[nb_pts_control_X*nb_pts_control_Y];
+  if(!m_posXYZ){
+    nb_pts_control_X=0;
+    nb_pts_control_Y=0;
+  }
+  for (x=0; x < nb_pts_control_X; x++)
+    for (y=0; y < nb_pts_control_Y; y++) {
+      int a= x + y * nb_pts_control_X;
+      m_posXYZ[a].x= (float)x/nb_pts_control_X;
+      m_posXYZ[a].y= (float)y/nb_pts_control_Y;
+      m_posXYZ[a].z= 0.0;
+    }
+  
   setModified();
 }
 
@@ -101,9 +116,7 @@ void curve3d :: resolutionMess(int resolutionX, int resolutionY){
 /////////////////////////////////////////////////////////
 void curve3d :: gridMess(int gridX, int gridY){
   nb_pts_affich_X = (gridX < 2) ? 2 : gridX;
-  if (nb_pts_affich_X > NUM_PNTS_MAX)  nb_pts_affich_X = NUM_PNTS_MAX ;
   nb_pts_affich_Y = (gridY < 2) ? 2 : gridY;
-  if (nb_pts_affich_Y > NUM_PNTS_MAX)  nb_pts_affich_Y = NUM_PNTS_MAX ;
   setModified();
 }
 
@@ -136,30 +149,34 @@ void curve3d :: typeMess(t_symbol *type){
     m_drawType = 10; 
   else if (!strcmp(type->s_name, "control_line2"))
     m_drawType = 11; 
+  else if (!strcmp(type->s_name, "default"))
+    m_drawType = 1;
   else    {
-    error ("GEM : no ripple draw style?");
+    error ("unknown draw style");
     return;
   }
   setModified();
 }
 
 //////////////////////////////////////////////////////////
-// render
+// renderShape
 //
 /////////////////////////////////////////////////////////
-void curve3d :: render(GemState *state){
+void curve3d :: renderShape(GemState *state){
+  if(m_drawType==GL_DEFAULT_GEM)m_drawType=1;
   float norm[3];
+  int n, m;
 
   glNormal3f(0.0f, 0.0f, 1.0f);
   glLineWidth(m_linewidth);
-  glMap2f(GL_MAP2_VERTEX_3, 0.0, 1.0, 3, (GLint)nb_pts_control_X, 0,1,(GLint)(3*nb_pts_control_X),(GLint)nb_pts_control_Y, &(posXYZ[0][0]));
+  glMap2f(GL_MAP2_VERTEX_3, 0.0, 1.0, 3, (GLint)nb_pts_control_X, 0,1,(GLint)(3*nb_pts_control_X),(GLint)nb_pts_control_Y, &(m_posXYZ[0].x));
   glEnable(GL_MAP2_VERTEX_3);
 
   GLfloat xsize = 1.0f;
   GLfloat ysize = 1.0f;
   GLfloat ysize0= 0.0f;
 
-  if (state->texture)
+  if (state->texture && state->numTexCoords>=3)
     {
       xsize  = state->texCoords[1].s;
       ysize0 = state->texCoords[2].t;
@@ -171,33 +188,33 @@ void curve3d :: render(GemState *state){
     //line
   case 0:    { 
     if (state->texture)	{
-      for (int n = 0; n < nb_pts_affich_X+1; n++)   {
+      for (n = 0; n < nb_pts_affich_X+1; n++)   {
 	glBegin(GL_LINE_STRIP);
-	for (int m = 0; m  < nb_pts_affich_Y+1; m++){	
+	for (m = 0; m  < nb_pts_affich_Y+1; m++){	
 	  glTexCoord2f(xsize*(GLfloat)n/(float)nb_pts_affich_X, ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
 	  glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	}
 	glEnd();
       }
-      for (int m = 0; m < nb_pts_affich_Y+1; m++) {
+      for(m = 0; m < nb_pts_affich_Y+1; m++) {
 	glBegin(GL_LINE_STRIP);
-	for (int n = 0; n  < nb_pts_affich_X+1; n++){
+	for(n = 0; n  < nb_pts_affich_X+1; n++){
 	  glTexCoord2f(xsize*(GLfloat)n/(float)nb_pts_affich_X, ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
 	  glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	}
 	glEnd();
       }
     }  else {
-	  for (int n = 0; n < nb_pts_affich_X+1; n++)  {
+	  for(n = 0; n < nb_pts_affich_X+1; n++)  {
 	    glBegin(GL_LINE_STRIP);
-	    for (int m = 0; m  < nb_pts_affich_Y+1; m++){	
+	    for(m = 0; m  < nb_pts_affich_Y+1; m++){	
 	      glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	    }
 	    glEnd();
 	  }
-	  for (int m = 0; m < nb_pts_affich_Y+1; m++)  {
+	  for(m = 0; m < nb_pts_affich_Y+1; m++)  {
 	    glBegin(GL_LINE_STRIP);
-	    for (int n = 0; n  < nb_pts_affich_X+1; n++){	
+	    for(n = 0; n  < nb_pts_affich_X+1; n++){	
 	      glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	    }
 	    glEnd();
@@ -209,9 +226,9 @@ void curve3d :: render(GemState *state){
   case 1:
     {
       if (state->texture)
-	for (int n = 0; n < nb_pts_affich_X; n++) {
+	for(n = 0; n < nb_pts_affich_X; n++) {
 	  glBegin(GL_TRIANGLE_STRIP);
-	  for (int m = 0; m  < nb_pts_affich_Y+1; m++)   {	
+	  for(m = 0; m  < nb_pts_affich_Y+1; m++)   {	
 	    glTexCoord2f(xsize*(GLfloat)n/(float)nb_pts_affich_X, ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	    glTexCoord2f(xsize*(GLfloat)(n+1)/(float)nb_pts_affich_X, ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
@@ -220,9 +237,9 @@ void curve3d :: render(GemState *state){
 	  glEnd();
 	}
       else
-	for (int n = 0; n < nb_pts_affich_X; n++) {
+	for(n = 0; n < nb_pts_affich_X; n++) {
 	  glBegin(GL_TRIANGLE_STRIP);
-	  for (int m = 0; m  < nb_pts_affich_Y+1; m++)  {	
+	  for(m = 0; m  < nb_pts_affich_Y+1; m++)  {	
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	    glEvalCoord2f((GLfloat)(n+1)/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	  }
@@ -235,15 +252,15 @@ void curve3d :: render(GemState *state){
     {
       glBegin(GL_POINTS);
       if (state->texture)
-	for (int n = 0; n < nb_pts_affich_X+1; n++) {
-	  for (int m = 0; m  < nb_pts_affich_Y+1; m++) {
+	for(n = 0; n < nb_pts_affich_X+1; n++) {
+	  for(m = 0; m  < nb_pts_affich_Y+1; m++) {
 	    glTexCoord2f(xsize*(GLfloat)n/(float)nb_pts_affich_X, ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	  }
 	}
       else
-	for (int n = 0; n < nb_pts_affich_X+1; n++) {
-	  for (int m = 0; m  < nb_pts_affich_Y+1; m++)
+	for(n = 0; n < nb_pts_affich_X+1; n++) {
+	  for(m = 0; m  < nb_pts_affich_Y+1; m++)
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	}
       glEnd();
@@ -254,18 +271,18 @@ void curve3d :: render(GemState *state){
     // line1
     {
       if (state->texture)
-	for (int n = 0; n < nb_pts_affich_X; n++) {
+	for(n = 0; n < nb_pts_affich_X; n++) {
 	  glBegin(GL_LINE_STRIP);
-	  for (int m = 0; m  < nb_pts_affich_Y; m++)  {	
+	  for(m = 0; m  < nb_pts_affich_Y; m++)  {	
 	    glTexCoord2f(xsize*(GLfloat)n/(float)nb_pts_affich_X, ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	  }
 	  glEnd();
 	}
       else
-	for (int n = 0; n < nb_pts_affich_X; n++) {
+	for(n = 0; n < nb_pts_affich_X; n++) {
 	  glBegin(GL_LINE_STRIP);
-	  for (int m = 0; m  < nb_pts_affich_Y; m++)   {	
+	  for(m = 0; m  < nb_pts_affich_Y; m++)   {	
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);	
 	  }
 	  glEnd();
@@ -277,18 +294,18 @@ void curve3d :: render(GemState *state){
     //line2
     {
       if (state->texture)
-	for (int m = 0; m < nb_pts_affich_Y+1; m++) {
+	for(m = 0; m < nb_pts_affich_Y+1; m++) {
 	  glBegin(GL_LINE_STRIP);
-	  for (int n = 0; n  < nb_pts_affich_X+1; n++)  {	
+	  for(n = 0; n  < nb_pts_affich_X+1; n++)  {	
 	    glTexCoord2f(xsize*(GLfloat)n/(float)nb_pts_affich_X,ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	  }
 	  glEnd();
 	}
       else
-	for (int m = 0; m < nb_pts_affich_Y+1; m++) {
+	for(m = 0; m < nb_pts_affich_Y+1; m++) {
 	  glBegin(GL_LINE_STRIP);
-	  for (int n = 0; n  < nb_pts_affich_X+1; n++)  {	
+	  for(n = 0; n  < nb_pts_affich_X+1; n++)  {	
 	    glTexCoord2f(xsize*(GLfloat)n/(float)nb_pts_affich_X, ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	  }
@@ -301,9 +318,9 @@ void curve3d :: render(GemState *state){
     //line3
     {
       if (state->texture)
-	for (int n = 0; n < nb_pts_affich_X; n++) {
+	for(n = 0; n < nb_pts_affich_X; n++) {
 	  glBegin(GL_LINES);
-	  for (int m = 0; m  < nb_pts_affich_Y; m++)
+	  for(m = 0; m  < nb_pts_affich_Y; m++)
 	    {
 	      glTexCoord2f(xsize*(GLfloat)n/(float)nb_pts_affich_X, ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
 	      glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
@@ -311,9 +328,9 @@ void curve3d :: render(GemState *state){
 	  glEnd();
 	}
       else
-	for (int n = 0; n < nb_pts_affich_X; n++) {
+	for(n = 0; n < nb_pts_affich_X; n++) {
 	  glBegin(GL_LINES);
-	  for (int m = 0; m  < nb_pts_affich_Y; m++)  {	
+	  for(m = 0; m  < nb_pts_affich_Y; m++)  {	
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);	
 	  }
 	  glEnd();
@@ -325,19 +342,19 @@ void curve3d :: render(GemState *state){
     //line4
     {
       if (state->texture)
-	for (int m = 0; m < nb_pts_affich_Y; m++)
+	for(m = 0; m < nb_pts_affich_Y; m++)
 	  {
 	    glBegin(GL_LINES);
-	    for (int n = 0; n  < nb_pts_affich_X; n++) {	
+	    for(n = 0; n  < nb_pts_affich_X; n++) {	
 	      glTexCoord2f(xsize*(GLfloat)n/(float)nb_pts_affich_X, ysize+ysizediff*(GLfloat)m/(float)nb_pts_affich_Y);
 	      glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);
 	    }
 	    glEnd();
 	  }
       else
-	for (int m = 0; m < nb_pts_affich_Y; m++) {
+	for(m = 0; m < nb_pts_affich_Y; m++) {
 	  glBegin(GL_LINES);
-	  for (int n = 0; n  < nb_pts_affich_X; n++) {	
+	  for(n = 0; n  < nb_pts_affich_X; n++) {	
 	    glEvalCoord2f((GLfloat)n/(float)nb_pts_affich_X, (GLfloat)m/(float)nb_pts_affich_Y);	
 	  }
 	  glEnd();
@@ -349,49 +366,66 @@ void curve3d :: render(GemState *state){
     // control_fill 
     {	
       if (state->texture)
-	for (int n = 0; n < nb_pts_control_X-1; n++)
-	  for (int m = 0; m  < nb_pts_control_Y-1; m++)   {
-	    Matrix::generateNormal(posXYZ[n+m*nb_pts_control_X],posXYZ[n+m*nb_pts_control_X+1], posXYZ[n+(m+1)*nb_pts_control_X], norm);
+	for(n = 0; n < nb_pts_control_X-1; n++)
+	  for(m = 0; m  < nb_pts_control_Y-1; m++)   {
+	    Matrix::generateNormal((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X],
+                                   (GLfloat*)&m_posXYZ[n+m*nb_pts_control_X+1], 
+                                   (GLfloat*)&m_posXYZ[n+(m+1)*nb_pts_control_X], 
+                                   norm);
 	    glNormal3fv(norm);
 
 	    glBegin(GL_TRIANGLE_STRIP);
-	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);	    
-	    glTexCoord2f(xsize*(GLfloat)(n+1)/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X+1]);
-	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)(m+1)/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+(m+1)*nb_pts_control_X]);
+	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);	    
+	    glTexCoord2f(xsize*(GLfloat)(n+1)/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X+1]);
+	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)(m+1)/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+(m+1)*nb_pts_control_X]);
 	    glEnd();
 
-	    Matrix::generateNormal(posXYZ[n+1+(m+1)*nb_pts_control_X],posXYZ[n+1+m*nb_pts_control_X], posXYZ[n+(m+1)*nb_pts_control_X], norm);
+	    Matrix::generateNormal((GLfloat*)&m_posXYZ[n+1+(m+1)*nb_pts_control_X],
+                                   (GLfloat*)&m_posXYZ[n+1+m*nb_pts_control_X], 
+                                   (GLfloat*)&m_posXYZ[n+(m+1)*nb_pts_control_X], norm);
 	    glNormal3fv(norm);
 	    glBegin(GL_TRIANGLE_STRIP);
-	    glTexCoord2f(xsize*(GLfloat)(n+1)/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)(m+1)/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+1+(m+1)*nb_pts_control_X]);
-	    glTexCoord2f(xsize*(GLfloat)(n+1)/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+1+m*nb_pts_control_X]);
-	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)(m+1)/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+(m+1)*nb_pts_control_X]);
+	    glTexCoord2f(xsize*(GLfloat)(n+1)/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)(m+1)/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+1+(m+1)*nb_pts_control_X]);
+	    glTexCoord2f(xsize*(GLfloat)(n+1)/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+1+m*nb_pts_control_X]);
+	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)(m+1)/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+(m+1)*nb_pts_control_X]);
 	    glEnd();
 	  }
       else
-	for (int n = 0; n < nb_pts_control_X-1; n++)
-	  for (int m = 0; m  < nb_pts_control_Y-1; m++)    {
-	    Matrix::generateNormal(posXYZ[n+m*nb_pts_control_X],posXYZ[n+m*nb_pts_control_X+1], posXYZ[n+(m+1)*nb_pts_control_X], norm);
+	for(n = 0; n < nb_pts_control_X-1; n++)
+	  for(m = 0; m  < nb_pts_control_Y-1; m++)    {
+	    Matrix::generateNormal((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X],
+                                   (GLfloat*)&m_posXYZ[n+m*nb_pts_control_X+1], 
+                                   (GLfloat*)&m_posXYZ[n+(m+1)*nb_pts_control_X], 
+                                   norm);
 	    glNormal3fv(norm);
 
 	    glBegin(GL_TRIANGLE_STRIP);
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X+1]);
-	    glVertex3fv(posXYZ[n+(m+1)*nb_pts_control_X]);
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X+1]);
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+(m+1)*nb_pts_control_X]);
 	    glEnd();
 
-	    Matrix::generateNormal(posXYZ[n+1+(m+1)*nb_pts_control_X],posXYZ[n+(1+m)*nb_pts_control_X], posXYZ[n+1+m*nb_pts_control_X], norm);
+	    Matrix::generateNormal((GLfloat*)&m_posXYZ[n+1+(m+1)*nb_pts_control_X],
+                                   (GLfloat*)&m_posXYZ[n+(1+m)*nb_pts_control_X],
+                                   (GLfloat*)&m_posXYZ[n+1+m*nb_pts_control_X], 
+                                   norm);
 	    glNormal3fv(norm);
 	    glBegin(GL_TRIANGLE_STRIP);
-	    glVertex3fv(posXYZ[n+1+(m+1)*nb_pts_control_X]);
-	    glVertex3fv(posXYZ[n+(m+1)*nb_pts_control_X]);
-	    glVertex3fv(posXYZ[n+1+m*nb_pts_control_X]);
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+1+(m+1)*nb_pts_control_X]);
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+(m+1)*nb_pts_control_X]);
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+1+m*nb_pts_control_X]);
 	    glEnd();
 	  }
     }
@@ -401,18 +435,19 @@ void curve3d :: render(GemState *state){
     // point de control de la structure (control_point)
     {
       if (state->texture)
-	for (int n = 0; n < nb_pts_control_X; n++)
-	  for (int m = 0; m  < nb_pts_control_Y; m++)   {	
+	for(n = 0; n < nb_pts_control_X; n++)
+	  for(m = 0; m  < nb_pts_control_Y; m++)   {	
 	    glBegin(GL_POINTS);
-	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);
+	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);
 	    glEnd();
 	  }
       else
-	for (int n = 0; n < nb_pts_control_X; n++)
-	  for (int m = 0; m  < nb_pts_control_Y; m++) {	
+	for(n = 0; n < nb_pts_control_X; n++)
+	  for(m = 0; m  < nb_pts_control_Y; m++) {	
 	    glBegin(GL_POINTS);	
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);
 	    glEnd();
 	  }
     }
@@ -422,34 +457,36 @@ void curve3d :: render(GemState *state){
     //control_line
     {
       if (state->texture){
-	for (int n = 0; n < nb_pts_control_X; n++)   {
+	for(n = 0; n < nb_pts_control_X; n++)   {
 	  glBegin(GL_LINE_STRIP);
-	  for (int m = 0; m  < nb_pts_control_Y; m++){	
-	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);
+	  for(m = 0; m  < nb_pts_control_Y; m++){	
+	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);
 	  }
 	  glEnd();
 	}
 
-	for (int m = 0; m < nb_pts_control_Y; m++)  {
+	for(m = 0; m < nb_pts_control_Y; m++)  {
 	  glBegin(GL_LINE_STRIP);
-	  for (int n = 0; n  < nb_pts_control_X; n++){
-	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);
+	  for(n = 0; n  < nb_pts_control_X; n++){
+	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);
 	  }
 	  glEnd();
 	}
       }  else	{
-	for (int n = 0; n < nb_pts_control_X; n++)  {
+	for(n = 0; n < nb_pts_control_X; n++)  {
 	  glBegin(GL_LINE_STRIP);
-	  for (int m = 0; m  < nb_pts_control_Y; m++)
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);
+	  for(m = 0; m  < nb_pts_control_Y; m++)
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);
 	  glEnd();
 	}
-	for (int m = 0; m < nb_pts_control_Y; m++)  {
+	for(m = 0; m < nb_pts_control_Y; m++)  {
 	  glBegin(GL_LINE_STRIP);
-	  for (int n = 0; n  < nb_pts_control_X; n++)	
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);				
+	  for(n = 0; n  < nb_pts_control_X; n++)	
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);				
 	  glEnd();
 	}
       }
@@ -460,19 +497,20 @@ void curve3d :: render(GemState *state){
     //control_line2
     {
       if (state->texture)
-	for (int m = 0; m < nb_pts_control_Y; m++) {
+	for(m = 0; m < nb_pts_control_Y; m++) {
 	  glBegin(GL_LINE_STRIP);
-	  for (int n = 0; n  < nb_pts_control_X; n++) {
-	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);			
+	  for(n = 0; n  < nb_pts_control_X; n++) {
+	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);			
 	  }
 	  glEnd();
 	}
       else
-	for (int m = 0; m < nb_pts_control_Y; m++) {
+	for(m = 0; m < nb_pts_control_Y; m++) {
 	  glBegin(GL_LINE_STRIP);
-	  for (int n = 0; n  < nb_pts_control_X; n++)
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);	
+	  for(n = 0; n  < nb_pts_control_X; n++)
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);	
 	  glEnd();
 	}
     }
@@ -482,19 +520,20 @@ void curve3d :: render(GemState *state){
     //control_line1
     {
       if (state->texture)
-	for (int n = 0; n < nb_pts_control_X; n++) {
+	for(n = 0; n < nb_pts_control_X; n++) {
 	  glBegin(GL_LINE_STRIP);
-	  for (int m = 0; m  < nb_pts_control_Y; m++)  {	
-	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);			
+	  for(m = 0; m  < nb_pts_control_Y; m++)  {	
+	    glTexCoord2f(xsize*(GLfloat)n/(nb_pts_control_X-1),
+                         ysize+ysizediff*(GLfloat)m/(nb_pts_control_Y-1));
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);			
 	  }
 	  glEnd();
 	}
       else
-	for (int n = 0; n < nb_pts_control_X; n++) {
+	for(n = 0; n < nb_pts_control_X; n++) {
 	  glBegin(GL_LINE_STRIP);
-	  for (int m = 0; m  < nb_pts_control_Y; m++)
-	    glVertex3fv(posXYZ[n+m*nb_pts_control_X]);
+	  for(m = 0; m  < nb_pts_control_Y; m++)
+	    glVertex3fv((GLfloat*)&m_posXYZ[n+m*nb_pts_control_X]);
 	  glEnd();
 	}
     }
@@ -513,8 +552,6 @@ void curve3d :: obj_setupCallback(t_class *classPtr){
 		  gensym("grid"), A_FLOAT, A_FLOAT, A_NULL);
   class_addmethod(classPtr, (t_method)&curve3d::setMessCallback,
 		  gensym("set"), A_FLOAT, A_FLOAT, A_FLOAT, A_FLOAT, A_FLOAT, A_NULL);
-  class_addmethod(classPtr, (t_method)&curve3d::typeMessCallback,
-		  gensym("draw"), A_SYMBOL, A_NULL);
 }
 
 void curve3d :: resolutionMessCallback(void *data, t_floatarg resX, t_floatarg resY)
@@ -529,7 +566,4 @@ void curve3d :: setMessCallback(void *data, float X, float Y, float posX, float
 {
   GetMyClass(data)->setMess((int)X, (int)Y, posX, posY, posZ);
 }
-void curve3d :: typeMessCallback(void *data, t_symbol *type)
-{
-  GetMyClass(data)->typeMess(type);
-}
+
