@@ -5,6 +5,8 @@ LOG
     A sphere
 
     Copyright (c) 1997-1998 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -36,7 +38,7 @@ class GEM_EXTERN sphere : public GemGluObj
 
         //////////
         // Constructor
-    	sphere(t_floatarg size);
+  sphere(t_floatarg size, t_floatarg slice=10.0);
     	
     protected:
     	
@@ -47,6 +49,16 @@ class GEM_EXTERN sphere : public GemGluObj
     	//////////
     	// Do the rendering
     	virtual void 	render(GemState *state);
+
+        virtual void  	createSphere(GemState *state);
+
+        float		*m_x;
+        float		*m_y;
+        float		*m_z;
+        int 		oldStacks, oldSlices;
+        GLenum		oldDrawType;
+	int             oldTexture;
+        
 };
 
 #endif	// for header file
