@@ -7,6 +7,7 @@ LOG
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
     Copyright (c) Gnther Geiger. geiger@epy.co.at
     Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    Copyright (c) 2005 Georg Holzmann <grh@mur.at>
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -17,10 +18,6 @@ LOG
 
 #include "Base/TextBase.h"
 
-#ifdef GLTT
-#include "GLTTOutlineFont.h"
-#endif
-
 /*-----------------------------------------------------------------
 -------------------------------------------------------------------
 CLASS
@@ -49,16 +46,6 @@ class GEM_EXTERN textoutline : public TextBase
 
 #ifdef FTGL
 	virtual FTFont*makeFont(const char*fontname);
-#elif defined GLTT
-	virtual void    destroyFont();
-	virtual int     makeFontFromFace();
-	//////////
-    	// The font structure
-    	GLTTOutlineFont		*m_font;
-
-    	//////////
-    	// Do the rendering
-    	virtual void 	render(GemState *state);
 #endif
 };
 
