@@ -5,6 +5,8 @@ LOG
 	Use orthogonal viewing
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -60,12 +62,19 @@ class GEM_EXTERN ortho : public GemBase
     	//////////
     	// Ortho changed
     	void	    	orthoMess(int state);
+
+    	//////////
+    	// Compatibility
+    	int	    		m_compat;
+    	void	    	compatMess(int state);
+
     	
     private:
     	
     	//////////
     	// static member functions
-    	static void 	orthoMessCallback(void *data, t_floatarg state);
+     	static void 	orthoMessCallback(void *data, t_floatarg state);
+   	static void 	compatMessCallback(void *data, t_floatarg state);
 };
 
 #endif	// for header file
