@@ -27,22 +27,41 @@ CPPEXTERN_NEW_WITH_ONE_ARG(light, t_floatarg, A_DEFFLOAT)
 //
 /////////////////////////////////////////////////////////
 light :: light(t_floatarg lightNum)
-	   : world_light(lightNum)
+  : world_light(lightNum)
 {
-    m_position[0] = m_position[1] = m_position[2] = 0.0;
-    m_position[3] = 1.0;
+  m_position[0] = m_position[1] = m_position[2] = 0.0;
+  m_position[3] = 1.0;
 }
 
-/////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////
 // Destructor
 //
-/////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////
 light :: ~light()
 { }
 
-/////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////
+// render
+//
+////////////////////////////////////////////////////////
+void light :: renderDebug()
+{
+  const GLfloat size=0.2f;
+  if (m_debug)
+    {
+      glPushMatrix();
+      glDisable(GL_LIGHTING);
+      glColor3fv(m_color);
+      glTranslatef(m_position[0], m_position[1], m_position[2]);
+      gluSphere(m_thing, size, 10, 10);
+      glEnable(GL_LIGHTING);
+      glPopMatrix();
+    }
+}
+
+////////////////////////////////////////////////////////
 // static member functions
 //
-/////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////
 void light :: obj_setupCallback(t_class *classPtr)
 { }
