@@ -5,6 +5,8 @@ LOG
 	Draw a particle group
 
     Copyright (c) 1997-1999 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -47,7 +49,7 @@ class GEM_EXTERN part_draw : public GemBase
 
     	//////////
     	// How the object should be drawn
-		void			typeMess(t_symbol *type);
+		void			typeMess(int,t_atom*);
     	
 		//////////
 		int				m_drawType;
@@ -56,7 +58,7 @@ class GEM_EXTERN part_draw : public GemBase
 
 		//////////
 		// static member functions
-		static void 	typeMessCallback(void *data, t_symbol *type);
+		static void 	typeMessCallback(void *data,  t_symbol *s,int,t_atom *);
 };
 
 #endif	// for header file
