@@ -29,7 +29,7 @@ CPPEXTERN_NEW_WITH_FOUR_ARGS(part_velsphere, t_floatarg, A_DEFFLOAT, t_floatarg,
 part_velsphere :: part_velsphere(t_floatarg xpos, t_floatarg ypos, t_floatarg zpos, t_floatarg rad)
   : m_radius(rad)
 {
-  post("part_velsphere: this is obsolete, use [part_velocity sphere <x> <y> <z> <r>] instead");
+  error("this is obsolete, use [part_velocity sphere <x> <y> <z> <r>] instead");
 
   m_pos[0] = xpos;
   m_pos[1] = ypos;
@@ -52,11 +52,10 @@ part_velsphere :: ~part_velsphere()
 /////////////////////////////////////////////////////////
 void part_velsphere :: render(GemState *state)
 {
-  if (state->stereo == 0 ||
-      state->stereo == 1)
+  if (state->tickTime > 0.f)
     {
       pVelocityD(PDSphere, m_pos[0], m_pos[1], m_pos[2], m_radius);
-    }	
+    }
 }
 
 /////////////////////////////////////////////////////////
