@@ -11,20 +11,11 @@
 
 #include "partlib_general.h"
 #include <float.h>
-#ifdef _WINDOWS
-/* jmz: at least my vc6 doesn't like linking against the "new" io-libraries
- * with <iostream.h> it links against the old libs */
-#include <iostream.h>
-#else
-#include <iostream>
-#endif
 
 #define SQRT2PI 2.506628274631000502415765284811045253006
 #define ONEOVERSQRT2PI (1. / SQRT2PI)
 
-#ifdef __APPLE__
-#include <macosx_math.h>
-#endif
+#include "Base/GemMath.h"
 
 // To offset [0 .. 1] vectors to [-.5 .. .5]
 static pVector vHalf(0.5, 0.5, 0.5);
@@ -854,7 +845,6 @@ void PAGravitate::Execute(ParticleGroup *group)
 				{
 					// Compute force exerted between the two bodies
 					pVector acc(tohim * (magdt / (sqrtf(tohimlenSqr) * (tohimlenSqr + epsilon))));
-					
 					m.vel += acc;
 					mj.vel -= acc;
 				}
