@@ -11,34 +11,6 @@
 
 #include <memory.h>
 
-// XXX
-#ifdef _WINDOWS
-/* jmz: at least my vc6 doesn't like <iostream> */
-#include <iostream.h>
-#else
-#include <iostream>
-#endif
-// using namespace std;
-/*
-// For Windows DLL.
-#ifdef WIN32
-BOOL APIENTRY DllMain( HANDLE hModule, 
-                       DWORD  ul_reason_for_call, 
-                       LPVOID lpReserved
-					 )
-{
-    switch (ul_reason_for_call)
-	{
-		case DLL_PROCESS_ATTACH:
-		case DLL_THREAD_ATTACH:
-		case DLL_THREAD_DETACH:
-		case DLL_PROCESS_DETACH:
-			break;
-    }
-    return TRUE;
-}
-#endif
-*/
 float ParticleAction::dt;
 
 ParticleGroup **_ParticleState::group_list;
