@@ -1,14 +1,22 @@
-/*
- *  pix_chroma_key.cpp
- *  gem_darwin
- *
- *  Created by chris clepper on Mon Oct 07 2002.
- *  Copyright (c) 2002 __MyCompanyName__. All rights reserved.
- *
- */
+/*-----------------------------------------------------------------
+LOG
+    GEM - Graphics Environment for Multimedia
+    pix_chroma_key.cpp
+    gem_darwin
+  
+    Created by chris clepper on Mon Oct 07 2002.
+    Copyright (c) 2002-2006 cgc. All rights reserved.
+ 
+    Copyright (c) 1997-2000 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
+    For information on usage and redistribution, and for a DISCLAIMER OF ALL
+    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
+
+-----------------------------------------------------------------*/
 
 #include "pix_chroma_key.h"
-#define CLAMP(x) ((x < 0) ? 0 : (x > 255) ? 255 : x)
+
 CPPEXTERN_NEW(pix_chroma_key)
 
 /////////////////////////////////////////////////////////
@@ -56,12 +64,12 @@ void pix_chroma_key :: processRGBA_RGBA(imageStruct &image, imageStruct &right)
   if (m_direction) {    
     while(datasize--){        
       if ((leftPix[chBlue] < Bhi)&&(leftPix[chBlue] > Blo)&&
-	  (leftPix[chRed] < Rhi)&&(leftPix[chRed] > Rlo)&&
-	  (leftPix[chGreen] < Ghi)&&(leftPix[chGreen] > Glo))
+	  (leftPix[chRed]  < Rhi)&&(leftPix[chRed]  > Rlo)&&
+	  (leftPix[chGreen]< Ghi)&&(leftPix[chGreen]> Glo))
 	{
-	  leftPix[chRed] = rightPix[chRed];
+	  leftPix[chRed]   = rightPix[chRed];
 	  leftPix[chGreen] = rightPix[chGreen];
-	  leftPix[chBlue] = rightPix[chBlue];
+	  leftPix[chBlue]  = rightPix[chBlue];
 	}
       leftPix+=4;
       rightPix+=4;
@@ -69,12 +77,12 @@ void pix_chroma_key :: processRGBA_RGBA(imageStruct &image, imageStruct &right)
   } else { //this needs help
     while(datasize--){
       if (!((leftPix[chBlue] < Bhi)&&(leftPix[chBlue] > Blo)&&
-            (leftPix[chRed] < Ghi)&&(leftPix[chRed] > Glo)&&
-            (leftPix[chGreen] < Rhi)&&(leftPix[chGreen] > Rlo)))
+            (leftPix[chRed]  < Rhi)&&(leftPix[chRed]  > Rlo)&&
+            (leftPix[chGreen]< Ghi)&&(leftPix[chGreen]> Glo)))
 	{
-	  leftPix[chRed] = rightPix[chRed];
+	  leftPix[chRed]   = rightPix[chRed];
 	  leftPix[chGreen] = rightPix[chGreen];
-	  leftPix[chBlue] = rightPix[chBlue];
+	  leftPix[chBlue]  = rightPix[chBlue];
 	}
       leftPix+=4;
       rightPix+=4;
@@ -89,11 +97,6 @@ void pix_chroma_key :: processRGBA_RGBA(imageStruct &image, imageStruct &right)
 /////////////////////////////////////////////////////////
 void pix_chroma_key :: processYUV_YUV(imageStruct &image, imageStruct &right)
 {
-#ifdef __VEC__
-processYUV_YUVAltivec(image, right);
-return;
-#else
-
    long src,h,w,xsize;
    unsigned char Uhi,Ulo,Vhi,Vlo,Yhi,Ylo;
    src =0;
@@ -248,18 +251,226 @@ return;
 	   src+=4;
 	 }
        }
-     }/**/
+     }
    }
-#endif //ALTIVEC
 }
 
+#ifdef __MMX__
+void pix_chroma_key :: processRGBA_MMX(imageStruct &image, imageStruct &right)
+{
+  int datasize = image.xsize * image.ysize * image.csize;
+  datasize=datasize/sizeof(__m64)+(datasize%sizeof(__m64)!=0);
+
+  __m64 *leftPix =  (__m64*)image.data;
+  __m64 *rightPix = (__m64*)right.data;
+
+
+  const __m64 hi=_mm_setr_pi8(CLAMP(m_Yvalue + m_Yrange), 
+			CLAMP(m_Uvalue + m_Urange),
+			CLAMP(m_Vvalue + m_Vrange),
+			(unsigned char)0xFF,
+			CLAMP(m_Yvalue + m_Yrange), 
+			CLAMP(m_Uvalue + m_Urange),
+			CLAMP(m_Vvalue + m_Vrange),
+			(unsigned char)0xFF);
+  const __m64 lo=_mm_setr_pi8(CLAMP(m_Yvalue - m_Yrange), 
+			CLAMP(m_Uvalue - m_Urange),
+			CLAMP(m_Vvalue - m_Vrange),
+			(unsigned char)0x00,
+			CLAMP(m_Yvalue - m_Yrange), 
+			CLAMP(m_Uvalue - m_Urange),
+			CLAMP(m_Vvalue - m_Vrange),
+			(unsigned char)0x00);
+
+  const __m64 null64=_mm_setzero_si64();
+
+  __m64 r, l, b0, b1;
+
+  if (m_direction) {    
+    while(datasize--){
+      l=leftPix [datasize];
+      r=rightPix[datasize];
+
+      b0=_mm_subs_pu8   (lo, l);
+      b1=_mm_subs_pu8   (l, hi);
+      b0=_mm_cmpeq_pi32 (b0, null64);
+      b1=_mm_cmpeq_pi32 (b1, null64);
+
+      b0=_mm_and_si64   (b0, b1);
+
+      b1=_mm_and_si64   (b0, r);
+      b0=_mm_andnot_si64(b0, l);
+
+      leftPix[datasize]=_mm_or_si64(b0, b1);
+    }
+  } else {
+    while(datasize--){
+      l=leftPix [datasize];
+      r=rightPix[datasize];
+
+      b0=_mm_subs_pu8   (lo, l);
+      b1=_mm_subs_pu8   (l, hi);
+      b0=_mm_cmpeq_pi32 (b0, null64);
+      b1=_mm_cmpeq_pi32 (b1, null64);
+
+      b0=_mm_and_si64   (b0, b1);
+
+      b1=_mm_and_si64   (b0, l);
+      b0=_mm_andnot_si64(b0, r);
+
+      leftPix[datasize]=_mm_or_si64(b0, b1);
+    }
+  }
+  _mm_empty();
+}
+
+void pix_chroma_key :: processYUV_MMX(imageStruct &image, imageStruct &right)
+{
+  int datasize = image.xsize * image.ysize * image.csize;
+  datasize=datasize/sizeof(__m64)+(datasize%sizeof(__m64)!=0);
+
+  __m64 *leftPix =  (__m64*)image.data;
+  __m64 *rightPix = (__m64*)right.data;
+
+  // no m_mode yet (does it make any sense at all ?)
+
+  const __m64 hi=_mm_setr_pi8(CLAMP(m_Uvalue + m_Urange), 
+			      CLAMP(m_Yvalue + m_Yrange),
+			      CLAMP(m_Vvalue + m_Vrange),
+			      CLAMP(m_Yvalue + m_Yrange),
+			      CLAMP(m_Uvalue + m_Urange), 
+			      CLAMP(m_Yvalue + m_Yrange),
+			      CLAMP(m_Vvalue + m_Vrange),
+			      CLAMP(m_Yvalue + m_Yrange));
+  const __m64 lo=_mm_setr_pi8(CLAMP(m_Uvalue - m_Urange), 
+			      CLAMP(m_Yvalue - m_Yrange),
+			      CLAMP(m_Vvalue - m_Vrange),
+			      CLAMP(m_Yvalue - m_Yrange),
+			      CLAMP(m_Uvalue - m_Urange), 
+			      CLAMP(m_Yvalue - m_Yrange),
+			      CLAMP(m_Vvalue - m_Vrange),
+			      CLAMP(m_Yvalue - m_Yrange));
+
+  const __m64 null64=_mm_setzero_si64();
+
+  __m64 r, l, b0, b1;
+
+  if (m_direction) {    
+    while(datasize--){
+      l=leftPix [datasize];
+      r=rightPix[datasize];
+
+      b0=_mm_subs_pu8   (lo, l);
+      b1=_mm_subs_pu8   (l, hi);
+      b0=_mm_cmpeq_pi32 (b0, null64);
+      b1=_mm_cmpeq_pi32 (b1, null64);
+
+      b0=_mm_and_si64   (b0, b1);
+
+      b1=_mm_and_si64   (b0, r);
+      b0=_mm_andnot_si64(b0, l);
+
+      leftPix[datasize]=_mm_or_si64(b0, b1);
+    }
+  } else {
+    while(datasize--){
+      l=leftPix [datasize];
+      r=rightPix[datasize];
+
+      b0=_mm_subs_pu8(lo, l);
+      b1=_mm_subs_pu8(l, hi);
+      b0=_mm_cmpeq_pi32(b0, null64);
+      b1=_mm_cmpeq_pi32(b1, null64);
+
+      b0=_mm_and_si64 (b0, b1);
+
+      b1=_mm_and_si64   (b0, l);
+      b0=_mm_andnot_si64(b0, r);
+
+      leftPix[datasize]=_mm_or_si64(b0, b1);
+    }
+  }
+  _mm_empty();
+}
+
+void pix_chroma_key :: processGray_MMX(imageStruct &image, imageStruct &right)
+{
+  int datasize = image.xsize * image.ysize * image.csize;
+  datasize=datasize/sizeof(__m64)+(datasize%sizeof(__m64)!=0);
+
+  __m64 *leftPix =  (__m64*)image.data;
+  __m64 *rightPix = (__m64*)right.data;
+
+  // no m_mode yet (does it make any sense at all ?)
+
+  const __m64 hi=_mm_setr_pi8(CLAMP(m_Yvalue + m_Yrange), 
+			      CLAMP(m_Yvalue + m_Yrange),
+			      CLAMP(m_Yvalue + m_Yrange),
+			      CLAMP(m_Yvalue + m_Yrange),
+			      CLAMP(m_Yvalue + m_Yrange), 
+			      CLAMP(m_Yvalue + m_Yrange),
+			      CLAMP(m_Yvalue + m_Yrange),
+			      CLAMP(m_Yvalue + m_Yrange));
+  const __m64 lo=_mm_setr_pi8(CLAMP(m_Yvalue - m_Yrange), 
+			      CLAMP(m_Yvalue - m_Yrange),
+			      CLAMP(m_Yvalue - m_Yrange),
+			      CLAMP(m_Yvalue - m_Yrange),
+			      CLAMP(m_Yvalue - m_Yrange), 
+			      CLAMP(m_Yvalue - m_Yrange),
+			      CLAMP(m_Yvalue - m_Yrange),
+			      CLAMP(m_Yvalue - m_Yrange));
+
+  const __m64 null64=_mm_setzero_si64();
+
+  __m64 r, l, b0, b1;
+
+  if (m_direction) {    
+    while(datasize--){
+      l=leftPix [datasize];
+      r=rightPix[datasize];
+
+      b0=_mm_subs_pu8   (lo, l);
+      b1=_mm_subs_pu8   (l, hi);
+      b0=_mm_cmpeq_pi32 (b0, null64);
+      b1=_mm_cmpeq_pi32 (b1, null64);
+
+      b0=_mm_and_si64   (b0, b1);
+
+      b1=_mm_and_si64   (b0, r);
+      b0=_mm_andnot_si64(b0, l);
+
+      leftPix[datasize]=_mm_or_si64(b0, b1);
+    }
+  } else {
+    while(datasize--){
+      l=leftPix [datasize];
+      r=rightPix[datasize];
+
+      b0=_mm_subs_pu8(lo, l);
+      b1=_mm_subs_pu8(l, hi);
+      b0=_mm_cmpeq_pi32(b0, null64);
+      b1=_mm_cmpeq_pi32(b1, null64);
+
+      b0=_mm_and_si64 (b0, b1);
+
+      b1=_mm_and_si64   (b0, l);
+      b0=_mm_andnot_si64(b0, r);
+
+      leftPix[datasize]=_mm_or_si64(b0, b1);
+    }
+  }
+  _mm_empty();
+}
+
+#endif
+
 /////////////////////////////////////////////////////////
 // the killer go fast stuff goes in here
 //
 /////////////////////////////////////////////////////////
-void pix_chroma_key :: processYUV_YUVAltivec(imageStruct &image, imageStruct &right)
-{
 #ifdef __VEC__
+void pix_chroma_key :: processYUV_Altivec(imageStruct &image, imageStruct &right)
+{
 register int h,w,i,j,width;
 
     h = image.ysize;
@@ -268,7 +479,7 @@ register int h,w,i,j,width;
     
     //check to see if the buffer isn't 16byte aligned (highly unlikely)
     if (image.ysize*image.xsize % 16 != 0){
-        post("pix_chroma_key: image not properly aligned for Altivec");
+        error("image not properly aligned for Altivec");
         return;
         }
 
@@ -453,12 +664,11 @@ register int h,w,i,j,width;
         }
         vec_dss(1);
         vec_dss(0);
+	}
+    */
     }
-*/
-    
-    }
-#endif
 }
+#endif
 
 
 /////////////////////////////////////////////////////////
@@ -493,14 +703,28 @@ void pix_chroma_key :: modeCallback(void *data, t_floatarg state)
 //make separate ranges for Y U V
 void pix_chroma_key :: rangeCallback(void *data, t_floatarg Yval, t_floatarg Uval,t_floatarg Vval)
 {
-  GetMyClass(data)->m_Yrange=((unsigned char)Yval);
-  GetMyClass(data)->m_Urange=((unsigned char)Uval);
-  GetMyClass(data)->m_Vrange=((unsigned char)Vval);
+  if(fabs(Yval)<=1.0 && fabs(Uval)<=1.0 && fabs(Vval)<=1.0) {
+    GetMyClass(data)->m_Yrange=((unsigned char)255*Yval);
+    GetMyClass(data)->m_Urange=((unsigned char)255*Uval);
+    GetMyClass(data)->m_Vrange=((unsigned char)255*Vval);
+  } else {
+    GetMyClass(data)->post("using deprecated un-normalized ranges (0..255): consider using (0..1) instead!");
+    GetMyClass(data)->m_Yrange=((unsigned char)Yval);
+    GetMyClass(data)->m_Urange=((unsigned char)Uval);
+    GetMyClass(data)->m_Vrange=((unsigned char)Vval);
+  }
 }
 
 void pix_chroma_key :: valueCallback(void *data, t_floatarg Yval, t_floatarg Uval, t_floatarg Vval)
 {
-  GetMyClass(data)->m_Yvalue=((unsigned char)Yval);
-  GetMyClass(data)->m_Uvalue=((unsigned char)Uval);
-  GetMyClass(data)->m_Vvalue=((unsigned char)Vval);
+  if(fabs(Yval)<=1.0 && fabs(Uval)<=1.0 && fabs(Vval)<=1.0) {
+    GetMyClass(data)->m_Yvalue=((unsigned char)255*Yval);
+    GetMyClass(data)->m_Uvalue=((unsigned char)255*Uval);
+    GetMyClass(data)->m_Vvalue=((unsigned char)255*Vval);
+  } else {
+    GetMyClass(data)->post("using deprecated un-normalized values (0..255): consider using (0..1) instead!");
+    GetMyClass(data)->m_Yvalue=((unsigned char)Yval);
+    GetMyClass(data)->m_Uvalue=((unsigned char)Uval);
+    GetMyClass(data)->m_Vvalue=((unsigned char)Vval);
+  }
 }
