@@ -67,6 +67,6 @@ void pix_coloralpha :: processRGBAImage(imageStruct &image)
 /////////////////////////////////////////////////////////
 void pix_coloralpha :: obj_setupCallback(t_class *)
 {
-  class_addcreator((t_newmethod)_classpix_coloralpha, 
+  class_addcreator((t_newmethod)create_pix_coloralpha, 
 		   gensym("pix_colouralpha"), A_NULL);
 }
