@@ -50,7 +50,6 @@ void pix_flip :: processRGBAImage(imageStruct &image)
     imageStruct tempImg;
     if (image.data==0)return;
     image.copy2Image(&tempImg);
-
     int ySrcStride = image.xsize * image.csize;
     int yDstStride = image.xsize * image.csize;
     int xSrcStride = image.csize;
@@ -58,13 +57,25 @@ void pix_flip :: processRGBAImage(imageStruct &image)
     unsigned char *srcLine = tempImg.data;
     unsigned char *dstLine = image.data;
 
-    switch(m_flip)
+    FlipType flip=m_flip;
+    if(image.upsidedown) {
+      switch(flip) {
+      case(HORIZONTAL) : flip=BOTH;break;
+      case(VERTICAL)   : flip=NONE;break;
+      case(BOTH)       : flip=HORIZONTAL;break;
+      case(NONE)       : flip=VERTICAL  ;break;
+      default   :break;
+      }
+    }
+    image.upsidedown=false;
+
+    switch(flip)
     {
-    	case(HOR):
+    	case(HORIZONTAL):
             srcLine = tempImg.data + ySrcStride - xSrcStride;
             xSrcStride = -xSrcStride;
     	    break;
-    	case(VERT):
+    	case(VERTICAL):
             srcLine = tempImg.data + ySrcStride * image.ysize - ySrcStride;
             ySrcStride = -ySrcStride;
     	    break;
@@ -95,7 +106,7 @@ void pix_flip :: processRGBAImage(imageStruct &image)
       }
       dstLine += yDstStride;
       srcLine += ySrcStride;
-    }   
+    }
 }
 
 /////////////////////////////////////////////////////////
@@ -116,13 +127,25 @@ void pix_flip :: processYUVImage(imageStruct &image)
     unsigned char *srcLine = tempImg.data;
     unsigned char *dstLine = image.data;
 
-    switch(m_flip)
+    FlipType flip=m_flip;
+    if(image.upsidedown) {
+      switch(flip) {
+      case(HORIZONTAL) : flip=BOTH;break;
+      case(VERTICAL)   : flip=NONE;break;
+      case(BOTH)       : flip=HORIZONTAL;break;
+      case(NONE)       : flip=VERTICAL  ;break;
+      default   :break;
+      }
+    }
+    image.upsidedown=false;
+
+    switch(flip)
     {
-    	case(HOR):
+    	case(HORIZONTAL):
             srcLine = tempImg.data + ySrcStride - xSrcStride;
             xSrcStride = -xSrcStride;
     	    break;
-    	case(VERT):
+    	case(VERTICAL):
             srcLine = tempImg.data + ySrcStride * image.ysize - ySrcStride;
             ySrcStride = -ySrcStride;
     	    break;
@@ -138,8 +161,8 @@ void pix_flip :: processYUVImage(imageStruct &image)
     int ySize = image.ysize;
     int xHold = image.xsize/2;
 
-    const int chY0x=(m_flip==VERT)?chY0:chY1;
-    const int chY1x=(m_flip==VERT)?chY1:chY0;
+    const int chY0x=(m_flip==VERTICAL)?chY0:chY1;
+    const int chY1x=(m_flip==VERTICAL)?chY1:chY0;
 
     while(ySize--)    {
       unsigned char *srcPixels = srcLine;
@@ -171,13 +194,25 @@ void pix_flip :: processGrayImage(imageStruct &image)
     unsigned char *srcLine = tempImg.data;
     unsigned char *dstLine = image.data;
 
-    switch(m_flip)
+    FlipType flip=m_flip;
+    if(image.upsidedown) {
+      switch(flip) {
+      case(HORIZONTAL) : flip=BOTH;break;
+      case(VERTICAL)   : flip=NONE;break;
+      case(BOTH)       : flip=HORIZONTAL;break;
+      case(NONE)       : flip=VERTICAL  ;break;
+      default   :break;
+      }
+    }
+    image.upsidedown=false;
+
+    switch(flip)
     {
-    	case(HOR):
+    	case(HORIZONTAL):
             srcLine = tempImg.data + ySrcStride - xSrcStride;
             xSrcStride = -xSrcStride;
     	    break;
-    	case(VERT):
+    	case(VERTICAL):
             srcLine = tempImg.data + ySrcStride * image.ysize - ySrcStride;
             ySrcStride = -ySrcStride;
     	    break;
@@ -236,11 +271,11 @@ void pix_flip :: obj_setupCallback(t_class *classPtr)
 }
 void pix_flip :: horMessCallback(void *data)
 {
-    GetMyClass(data)->flipMess(HOR);
+    GetMyClass(data)->flipMess(HORIZONTAL);
 }
 void pix_flip :: vertMessCallback(void *data)
 {
-    GetMyClass(data)->flipMess(VERT);
+    GetMyClass(data)->flipMess(VERTICAL);
 }
 void pix_flip :: bothMessCallback(void *data)
 {
@@ -254,8 +289,8 @@ void pix_flip :: flipMessCallback(void *data, t_symbol*s)
 {
   char c=*s->s_name;
   switch(c){
-  case 'v': case 'V':  GetMyClass(data)->flipMess(VERT); break;
-  case 'h': case 'H':  GetMyClass(data)->flipMess(HOR); break;
+  case 'v': case 'V':  GetMyClass(data)->flipMess(VERTICAL); break;
+  case 'h': case 'H':  GetMyClass(data)->flipMess(HORIZONTAL); break;
   case 'b': case 'B':  GetMyClass(data)->flipMess(BOTH); break;
   default:  GetMyClass(data)->flipMess(NONE);
   }
