@@ -45,7 +45,7 @@ class GEM_EXTERN pix_gain : public GemPixObj
 
 	    //////////
 	    // Constructor
-    	pix_gain();
+  pix_gain(int,t_atom*);
     	
     protected:
     	
@@ -58,9 +58,16 @@ class GEM_EXTERN pix_gain : public GemPixObj
     	virtual void 	processRGBAImage(imageStruct &image);
     	virtual void 	processGrayImage(imageStruct &image);
     	virtual void 	processYUVImage(imageStruct &image);
-    	 //////////
+#ifdef __MMX__
+	//////////
+    	// MMX
+    	virtual void 	processRGBAMMX(imageStruct &image);   
+#endif
+#ifdef __VEC__
+	//////////
     	// altivec
-    	virtual void 	processYUV_Altivec(imageStruct &image);   	
+    	virtual void 	processYUVAltivec(imageStruct &image);   	
+#endif
     	//////////
     	// Set the new gain
     	void	    	vecGainMess(int argc, t_atom *argv);
@@ -72,6 +79,13 @@ class GEM_EXTERN pix_gain : public GemPixObj
     	//////////
     	// The new gain
     	float		  	m_gain[4];
+
+   	//////////
+    	// Set the new gain
+    	void	    	saturateMess(int sat);
+
+	//////////
+	bool  m_saturate;
     
     private:
     
@@ -79,6 +93,7 @@ class GEM_EXTERN pix_gain : public GemPixObj
     	// Static member functions
     	static void 	vecGainMessCallback(void *data, t_symbol *, int argc, t_atom *argv);
     	static void 	floatGainMessCallback(void *data, t_floatarg gain);
+    	static void 	saturateMessCallback(void *data, t_floatarg saturate);
 };
 
 #endif	// for header file
