@@ -4,7 +4,9 @@ LOG
 
     Resizes an image
 
-    Copyright (c) 1997-1998 Mark Danks. mdanks@cybermed.ucsd.edu
+    Copyright (c) 1997-1998 Mark Danks. mark@danks.org
+    Copyright (c) Gnther Geiger. geiger@epy.co.at
+    Copyright (c) 2001-2002 IOhannes m zmoelnig. forum::fr::umlute. IEM. zmoelnig@iem.kug.ac.at
     For information on usage and redistribution, and for a DISCLAIMER OF ALL
     WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
 
@@ -34,7 +36,7 @@ class GEM_EXTERN pix_resize : public GemPixObj
 
 	    //////////
 	    // Constructor
-    	pix_resize();
+  pix_resize(t_floatarg w, t_floatarg h);
     	
     protected:
     	
@@ -44,7 +46,19 @@ class GEM_EXTERN pix_resize : public GemPixObj
 
     	//////////
     	// Do the processing
-    	virtual void 	processImage(imageStruct &image);
+	void 	processImage(imageStruct &image);
+	
+	//////////
+	// setting dimension and colourspace
+	void  dimenMess(int w, int h);
+	int           m_width, m_height;
+	imageStruct   m_image;
+
+ private:
+    	
+	//////////
+	// static member functions
+	static void   dimenMessCallback(void *data, t_float w, t_float h);	
 };
 
 #endif	// for header file
