@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLBLENDFUNC_H_
 #define INCLUDE_GEM_GLBLENDFUNC_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,13 +25,13 @@
 	"glBlendFunc( GLenum sfactor, GLenum dfactor)"
  */
 
-class GEM_EXTERN GEMglBlendFunc : public GemBase
+class GEM_EXTERN GEMglBlendFunc : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglBlendFunc, GemBase)
+	CPPEXTERN_HEADER(GEMglBlendFunc, GemGLBase)
 
 	public:
 	  // Constructor
-	  GEMglBlendFunc (t_float, t_float);	// CON
+	  GEMglBlendFunc (int, t_atom*); // CON
 
 	protected:
 	  // Destructor
@@ -42,10 +41,10 @@ class GEM_EXTERN GEMglBlendFunc : public GemBase
 
 	// variables
 	  GLenum	sfactor;		// VAR
-	  virtual void	sfactorMess(t_float);	// FUN
+	  virtual void	sfactorMess(t_atom);	// FUN
 
 	  GLenum	dfactor;		// VAR
-	  virtual void	dfactorMess(t_float);	// FUN
+	  virtual void	dfactorMess(t_atom);	// FUN
 
 
 	private:
@@ -54,7 +53,7 @@ class GEM_EXTERN GEMglBlendFunc : public GemBase
 	  t_inlet *m_inlet[2];
 
 	// static member functions
-	  static void	 sfactorMessCallback (void*, t_floatarg);
-	  static void	 dfactorMessCallback (void*, t_floatarg);
+	  static void	 sfactorMessCallback (void*,t_symbol*,int,t_atom*);
+	  static void	 dfactorMessCallback (void*,t_symbol*,int,t_atom*);
 };
 #endif // for header file
