@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLCLEARDEPTH_H_
 #define INCLUDE_GEM_GLCLEARDEPTH_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,9 +25,9 @@
 	"glClearDepth( GLclampd depth)"
  */
 
-class GEM_EXTERN GEMglClearDepth : public GemBase
+class GEM_EXTERN GEMglClearDepth : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglClearDepth, GemBase)
+	CPPEXTERN_HEADER(GEMglClearDepth, GemGLBase)
 
 	public:
 	  // Constructor
@@ -42,7 +41,7 @@ class GEM_EXTERN GEMglClearDepth : public GemBase
 
 	// variables
 	  GLclampd	depth;		// VAR
-	  virtual void	depthMess(GLclampd);	// FUN
+	  virtual void	depthMess(float);	// FUN
 
 
 	private:
@@ -51,6 +50,6 @@ class GEM_EXTERN GEMglClearDepth : public GemBase
 	  t_inlet *m_inlet[1];
 
 	// static member functions
-	  static void	 depthMessCallback (void*, GLclampd);
+	  static void	 depthMessCallback (void*, float);
 };
 #endif // for header file
