@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLDEPTHFUNC_H_
 #define INCLUDE_GEM_GLDEPTHFUNC_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,13 +25,13 @@
 	"glDepthFunc( GLenum func)"
  */
 
-class GEM_EXTERN GEMglDepthFunc : public GemBase
+class GEM_EXTERN GEMglDepthFunc : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglDepthFunc, GemBase)
+	CPPEXTERN_HEADER(GEMglDepthFunc, GemGLBase)
 
 	public:
 	  // Constructor
-	  GEMglDepthFunc (t_float);	// CON
+	  GEMglDepthFunc (int, t_atom*); // CON
 
 	protected:
 	  // Destructor
@@ -42,7 +41,7 @@ class GEM_EXTERN GEMglDepthFunc : public GemBase
 
 	// variables
 	  GLenum	func;		// VAR
-	  virtual void	funcMess(t_float);	// FUN
+	  virtual void	funcMess(t_atom);	// FUN
 
 
 	private:
@@ -51,6 +50,6 @@ class GEM_EXTERN GEMglDepthFunc : public GemBase
 	  t_inlet *m_inlet[1];
 
 	// static member functions
-	  static void	 funcMessCallback (void*, t_floatarg);
+	  static void	 funcMessCallback (void*,t_symbol*,int,t_atom*);
 };
 #endif // for header file
