@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLDISABLECLIENTSTATE_H_
 #define INCLUDE_GEM_GLDISABLECLIENTSTATE_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,23 +25,26 @@
 	"glDisableClientState( GLenum array)"
  */
 
-class GEM_EXTERN GEMglDisableClientState : public GemBase
+class GEM_EXTERN GEMglDisableClientState : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglDisableClientState, GemBase)
+	CPPEXTERN_HEADER(GEMglDisableClientState, GemGLBase)
 
 	public:
 	  // Constructor
-	  GEMglDisableClientState (t_float);	// CON
+	  GEMglDisableClientState (int, t_atom*); // CON
 
 	protected:
 	  // Destructor
 	  virtual ~GEMglDisableClientState ();
+          // check extensions
+          virtual bool isRunnable(void);
+
 	  // Do the rendering
 	  virtual void	render (GemState *state);
 
 	// variables
 	  GLenum	array;		// VAR
-	  virtual void	arrayMess(t_float);	// FUN
+	  virtual void	arrayMess(t_atom);	// FUN
 
 
 	private:
@@ -51,6 +53,6 @@ class GEM_EXTERN GEMglDisableClientState : public GemBase
 	  t_inlet *m_inlet[1];
 
 	// static member functions
-	  static void	 arrayMessCallback (void*, t_floatarg);
+	  static void	 arrayMessCallback (void*,t_symbol*,int,t_atom*);
 };
 #endif // for header file
