@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLENABLE_H_
 #define INCLUDE_GEM_GLENABLE_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,13 +25,13 @@
 	"glEnable( GLenum cap)"
  */
 
-class GEM_EXTERN GEMglEnable : public GemBase
+class GEM_EXTERN GEMglEnable : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglEnable, GemBase)
+	CPPEXTERN_HEADER(GEMglEnable, GemGLBase)
 
 	public:
 	  // Constructor
-	  GEMglEnable (t_float);	// CON
+	  GEMglEnable (int, t_atom*); // CON
 
 	protected:
 	  // Destructor
@@ -42,7 +41,7 @@ class GEM_EXTERN GEMglEnable : public GemBase
 
 	// variables
 	  GLenum	cap;		// VAR
-	  virtual void	capMess(t_float);	// FUN
+	  virtual void	capMess(t_atom);	// FUN
 
 
 	private:
@@ -51,6 +50,6 @@ class GEM_EXTERN GEMglEnable : public GemBase
 	  t_inlet *m_inlet[1];
 
 	// static member functions
-	  static void	 capMessCallback (void*, t_floatarg);
+	  static void	 capMessCallback (void*,t_symbol*,int,t_atom*);
 };
 #endif // for header file
