@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLEVALCOORD2DV_H_
 #define INCLUDE_GEM_GLEVALCOORD2DV_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,9 +25,9 @@
 	"glEvalCoord2dv( GLdouble *u glEvalCoord2dv GLdouble *u)"
  */
 
-class GEM_EXTERN GEMglEvalCoord2dv : public GemBase
+class GEM_EXTERN GEMglEvalCoord2dv : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglEvalCoord2dv, GemBase)
+	CPPEXTERN_HEADER(GEMglEvalCoord2dv, GemGLBase)
 
 	public:
 	  // Constructor
@@ -36,6 +35,9 @@ class GEM_EXTERN GEMglEvalCoord2dv : public GemBase
 	protected:
 	  // Destructor
 	  virtual ~GEMglEvalCoord2dv ();
+          // check extensions
+          virtual bool isRunnable(void);
+
 	  // Do the rendering
 	  virtual void	render (GemState *state);
 
