@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLFOGFV_H_
 #define INCLUDE_GEM_GLFOGFV_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -29,9 +28,9 @@
 #define FOG_ARRAY_LENGTH 4
 
 
-class GEM_EXTERN GEMglFogfv : public GemBase
+class GEM_EXTERN GEMglFogfv : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglFogfv, GemBase)
+	CPPEXTERN_HEADER(GEMglFogfv, GemGLBase)
 
 	public:
 	  // Constructor
@@ -39,6 +38,9 @@ class GEM_EXTERN GEMglFogfv : public GemBase
 	protected:
 	  // Destructor
 	  virtual ~GEMglFogfv ();
+          // check extensions
+          virtual bool isRunnable(void);
+
 	  // Do the rendering
 	  virtual void	render (GemState *state);
 
@@ -56,7 +58,7 @@ class GEM_EXTERN GEMglFogfv : public GemBase
 
 	// static member functions
          static void    pnameMessCallback (void*, t_float);
-         static void    paramsMessCallback (void*, int, t_atom*);
+         static void    paramsMessCallback (void*, t_symbol*, int, t_atom*);
 
 };
 #endif // for header file
