@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLFOGIV_H_
 #define INCLUDE_GEM_GLFOGIV_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -29,9 +28,9 @@
 #define FOG_ARRAY_LENGTH 4
 
 
-class GEM_EXTERN GEMglFogiv : public GemBase
+class GEM_EXTERN GEMglFogiv : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglFogiv, GemBase)
+	CPPEXTERN_HEADER(GEMglFogiv, GemGLBase)
 
 	public:
 	  // Constructor
@@ -39,6 +38,9 @@ class GEM_EXTERN GEMglFogiv : public GemBase
 	protected:
 	  // Destructor
 	  virtual ~GEMglFogiv ();
+          // check extensions
+          virtual bool isRunnable(void);
+
 	  // Do the rendering
 	  virtual void	render (GemState *state);
 
@@ -56,6 +58,6 @@ class GEM_EXTERN GEMglFogiv : public GemBase
 
 	// static member functions
          static void    pnameMessCallback (void*, t_float);
-         static void    paramsMessCallback (void*, int, t_atom*);
+         static void    paramsMessCallback (void*, t_symbol*, int, t_atom*);
 };
 #endif // for header file
