@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLGENTEXTURES_H_
 #define INCLUDE_GEM_GLGENTEXTURES_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,9 +25,9 @@
 	"glGenTextures( GLsizei n, GLuint *textures)"
  */
 
-class GEM_EXTERN GEMglGenTextures : public GemBase
+class GEM_EXTERN GEMglGenTextures : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglGenTextures, GemBase)
+	CPPEXTERN_HEADER(GEMglGenTextures, GemGLBase)
 
 	public:
 	  // Constructor
@@ -37,6 +36,9 @@ class GEM_EXTERN GEMglGenTextures : public GemBase
 	protected:
 	  // Destructor
 	  virtual ~GEMglGenTextures ();
+          // check extensions
+          virtual bool isRunnable(void);
+
 	  // Do the rendering
 	  virtual void	render (GemState *state);
 
@@ -52,6 +54,6 @@ class GEM_EXTERN GEMglGenTextures : public GemBase
 	  t_inlet *m_inlet;
 
 	// static member functions
-	  static void	 texturesMessCallback (void*, int, t_atom*);
+	  static void	 texturesMessCallback (void*, t_symbol*, int, t_atom*);
 };
 #endif // for header file
