@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLGETSTRING_H_
 #define INCLUDE_GEM_GLGETSTRING_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,9 +25,9 @@
 	"glGetString( glGetString  GLenum name )"
  */
 
-class GEM_EXTERN GEMglGetString : public GemBase
+class GEM_EXTERN GEMglGetString : public GemGLBase
 {
-  CPPEXTERN_HEADER(GEMglGetString, GemBase)
+  CPPEXTERN_HEADER(GEMglGetString, GemGLBase)
 
     public:
   // Constructor
@@ -42,7 +41,7 @@ class GEM_EXTERN GEMglGetString : public GemBase
   
   // variables
   GLenum name;		// VAR
-  virtual void	nameMess(t_float);	// FUN
+  virtual void	nameMess(t_atom);	// FUN
   
   // we need some inl/outets
   t_inlet *m_inlet;
@@ -51,6 +50,6 @@ class GEM_EXTERN GEMglGetString : public GemBase
  private:
 
   // static member functions
-  static void	 nameMessCallback (void*, t_floatarg);
+  static void	 nameMessCallback (void*, t_symbol*,int,t_atom*);
 };
 #endif // for header file
