@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLINDEXUB_H_
 #define INCLUDE_GEM_GLINDEXUB_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,9 +25,9 @@
 	"glIndexub( GLubyte c)"
  */
 
-class GEM_EXTERN GEMglIndexub : public GemBase
+class GEM_EXTERN GEMglIndexub : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglIndexub, GemBase)
+	CPPEXTERN_HEADER(GEMglIndexub, GemGLBase)
 
 	public:
 	  // Constructor
@@ -37,6 +36,9 @@ class GEM_EXTERN GEMglIndexub : public GemBase
 	protected:
 	  // Destructor
 	  virtual ~GEMglIndexub ();
+          // check extensions
+          virtual bool isRunnable(void);
+
 	  // Do the rendering
 	  virtual void	render (GemState *state);
 
