@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLISENABLED_H_
 #define INCLUDE_GEM_GLISENABLED_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,23 +25,26 @@
 	"glIsEnabled( glIsEnabled  GLenum cap )"
  */
 
-class GEM_EXTERN GEMglIsEnabled : public GemBase
+class GEM_EXTERN GEMglIsEnabled : public GemGLBase
 {
-  CPPEXTERN_HEADER(GEMglIsEnabled, GemBase)
+  CPPEXTERN_HEADER(GEMglIsEnabled, GemGLBase)
 
     public:
   // Constructor
-  GEMglIsEnabled (t_floatarg);	// CON
+  GEMglIsEnabled (int, t_atom*); // CON
 
  protected:
   // Destructor
   virtual ~GEMglIsEnabled ();
+          // check extensions
+          virtual bool isRunnable(void);
+
   // Do the rendering
   virtual void	render (GemState *state);
 
   // variables
   GLenum cap;		// VAR
-  virtual void	capMess(t_float);	// FUN
+  virtual void	capMess(t_atom);	// FUN
 
   // we need some inlets
   t_inlet *m_inlet;
@@ -51,6 +53,6 @@ class GEM_EXTERN GEMglIsEnabled : public GemBase
  private:
 
   // static member functions
-  static void	 capMessCallback (void*, t_floatarg);
+  static void	 capMessCallback (void*,t_symbol*,int,t_atom*);
 };
 #endif // for header file
