@@ -13,8 +13,7 @@
 #ifndef INCLUDE_GEM_GLNORMAL3S_H_
 #define INCLUDE_GEM_GLNORMAL3S_H_
 
-#include "Base/GemGLUtil.h"
-#include "Base/GemBase.h"
+#include "GemGLBase.h"
 
 /*
  CLASS
@@ -26,9 +25,9 @@
 	"glNormal3s( GLshort nx, GLshort ny, GLshort nz)"
  */
 
-class GEM_EXTERN GEMglNormal3s : public GemBase
+class GEM_EXTERN GEMglNormal3s : public GemGLBase
 {
-	CPPEXTERN_HEADER(GEMglNormal3s, GemBase)
+	CPPEXTERN_HEADER(GEMglNormal3s, GemGLBase)
 
 	public:
 	  // Constructor
